AccountMergeConfig constructor

const AccountMergeConfig({
  1. AccountMergeHandler? applicationMergeHandler = defaultMergeHandler,
})

Creates a new AccountMergeConfig instance with the default merge hooks.

Applications which have their own data to migrate should consider passing a callback for applicationMergeHandler which moves all relevant data from the user to remove to the user to keep. This function is then placed in the list of merge hooks just before the cleanup handler.

Applications which desire finer-grain control over the ordering of merge hooks should use the AccountMergeConfig.custom constructor. Re-use of some or all of the existing default merge handlers is still appropriate in this scenario, should you be using the custom constructor for reordering purposes or to override only some of the default handlers.

Implementation

const AccountMergeConfig({
  this.applicationMergeHandler = defaultMergeHandler,
}) : _mergeHooks = null;