AuthSuccess class abstract

Response model representing a successful authentication result with all relevant authentication information.

Available extensions

Constructors

AuthSuccess({required String authStrategy, required String token, DateTime? tokenExpiresAt, String? refreshToken, required UuidValue authUserId, required Set<String> scopeNames})
factory
AuthSuccess.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

authStrategy String
The authentication strategy used for this session.
getter/setter pair
authUserId ↔ UuidValue
The AuthUser this session belongs to.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jwtRefreshTokenId → UuidValue

Available on AuthSuccess, provided by the AuthSuccessJwtRefreshTokenId extension

Returns the JWT refresh token ID from the AuthSuccess.refreshToken.
no setter
refreshToken String?
Optional refresh token.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopeNames Set<String>
The scopes this session provides access to.
getter/setter pair
serverSideSessionId → UuidValue

Available on AuthSuccess, provided by the AuthSuccessServerSideSessionId extension

Returns the server side session token ID from the AuthSuccess.token.
no setter
token String
The authentication token, in the case of JWT this is the access token.
getter/setter pair
tokenExpiresAt DateTime?
The token expiration date in UTC, if any.
getter/setter pair

Methods

copyWith({String? authStrategy, String? token, DateTime? tokenExpiresAt, String? refreshToken, UuidValue? authUserId, Set<String>? scopeNames}) AuthSuccess
Returns a shallow copy of this AuthSuccess with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited