update method
Future<List<AuthUser> >
update(
- DatabaseSession session,
- List<
AuthUser> rows, { - ColumnSelections<
AuthUserTable> ? columns, - Transaction? transaction,
- bool noReturn = false,
Updates all AuthUsers in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
If noReturn is set to true, the updated rows are not read back from
the database and an empty list is returned. This avoids the overhead of
transferring and deserializing the rows when the result is not needed.
Implementation
Future<List<AuthUser>> update(
_i1.DatabaseSession session,
List<AuthUser> rows, {
_i1.ColumnSelections<AuthUserTable>? columns,
_i1.Transaction? transaction,
bool noReturn = false,
}) async {
return session.db.update<AuthUser>(
rows,
columns: columns?.call(AuthUser.t),
transaction: transaction,
noReturn: noReturn,
);
}