AuthUserTable class

Constructors

AuthUserTable({TableRelation? tableRelation})

Properties

blocked ↔ ColumnBool
If true the user will be blocked from signing in.
latefinal
columns → List<Column>
List of Column used by the table.
no setter
createdAt ↔ ColumnDateTime
The time when this user was created.
latefinal
hasColumnMapping → bool
Cached flag indicating whether any columns have explicit column names that differ from their field names. Computed lazily on first access.
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<UuidValue?>
The database id.
latefinalinherited
managedColumns → List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
queryPrefix → String
Query prefix for Columns of the table.
no setterinherited
quotedTableName → String
tableName quoted for the current dialect. Prefer it over tableName in raw SQL, since dialects quote schemas differently.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
Schema part of tableName, or null when the name is unqualified.
latefinalinherited
scopeNames ↔ ColumnSerializable<Set<String>>
Set of scopes that this user can access.
latefinal
tableName → String
Name of the table as used in the database, optionally qualified as schema.table.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited
unqualifiedTableName → String
tableName with the schema removed.
latefinalinherited
updateTable ↔ AuthUserUpdateTable
latefinal

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited