blocked property
ColumnBool
blocked
latefinal
If true the user will be blocked from signing in.
Implementation
late final _is.ColumnBool blocked;
If true the user will be blocked from signing in.
late final _is.ColumnBool blocked;