CompletionTokenResult class

Result of creating a completion token.

Constructors

CompletionTokenResult({required SecretChallenge challenge, required String encodedToken})
Creates a new CompletionTokenResult.
const

Properties

challenge → SecretChallenge
The created challenge that should be linked to the request.
final
encodedToken → String
The base64-encoded token to return to the client.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited