IdentityProvider class abstract

Contract implemented by all identity providers.

Implementers

Constructors

IdentityProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
The stable method identifier used when issuing authentication tokens.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

mergeAuthUsers(Session session, {required UuidValue userToKeepId, required UuidValue userToRemoveId, required Transaction transaction}) → Future<void>
Merges this provider's data from one auth user into another.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited