mergeAuthUsers abstract method

Future<void> mergeAuthUsers(
  1. Session session, {
  2. required UuidValue userToKeepId,
  3. required UuidValue userToRemoveId,
  4. required Transaction transaction,
})

Merges this provider's data from one auth user into another.

Providers without data that needs to be retained during an account merge should implement this as an explicit no-op. Providers that cannot merge safely should throw, which causes the account merge transaction to roll back.

Implementation

Future<void> mergeAuthUsers(
  final Session session, {
  required final UuidValue userToKeepId,
  required final UuidValue userToRemoveId,
  required final Transaction transaction,
});