IdentityProviderBuilder<T extends IdentityProvider> class abstract

Interface for building identity providers.

Responsible for building instances of identity providers with dependencies that can then be used by provider endpoints.

Implementers

Constructors

IdentityProviderBuilder()
Creates a new IdentityProviderBuilder instance.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setter

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) → T
Builds a new instance of the identity provider.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited