IdpBaseEndpoint class abstract
Base endpoint for identity providers.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logSessions → bool
-
States if
Sessions should be logged for this endpoint. Defaults to true, override to change.no setterinherited - moduleName → String?
-
The name of the current module, or null for the main server.
no setterinherited
- name → String
-
The name of this
Endpoint. It will be automatically generated from the name of the class (excluding any Endpoint suffix).no setterinherited - pod → Serverpod
-
The
ServerPodthisEndpointis running on.no setterinherited -
requiredScopes
→ Set<
Scope> -
List of
Scopes that are required to access thisEndpoint. Override this getter to setup custom requirements.no setterinherited - requireLogin → bool
-
States if the
Endpointonly should accept users that are authenticated. Default value is false, override to change.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendAsRaw → bool
-
If true, returned value from methods will be sent sent to the client
as raw data without any formatting. One use case is to return data through
a non-api call. Defaults to false, override to change. If used, the
endpoint method is responsible for correctly setting the contentType of
the http response (defaults to
text/plain).no setterinherited - server → Server
-
The
ServerthisEndpointis running on.no setterinherited
Methods
-
hasAccount(
Session session) → Future< bool> -
Returns the
methodvalue for each connectedIdpsubclass if the current session is authenticated and if the user has an account connected to theIdp. -
initialize(
Server server, String name, String? moduleName) → void -
Initializes the endpoint with the current
Server. Typically, this is done from generated code.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited