JwtAlgorithm class sealed

Configuration for an authentication token algorithm.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verificationKey → JWTKey
The key used to verify the JWT tokens.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

ecdsaSha512({required ECPrivateKey privateKey, required ECPublicKey publicKey}) → EcdsaSha512JwtAlgorithmConfiguration
Create a new ECDSA SHA-512 authentication token algorithm configuration.
hmacSha256(SecretKey key) → HmacSha256JwtAlgorithmConfiguration
Create a new HMAC SHA-256 authentication token algorithm configuration.
hmacSha512(SecretKey key) → HmacSha512JwtAlgorithmConfiguration
Create a new HMAC SHA-512 authentication token algorithm configuration.