OAuth2Exception class abstract

Base exception for OAuth2 token exchange operations.

All specific OAuth2 token exchange errors should extend this class.

Implemented types
Implementers

Constructors

OAuth2Exception(String message)
Creates a new OAuth2Exception object
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
A human-readable error message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited