OAuth2InvalidResponseException class

Thrown when the token response could not be parsed as valid JSON.

Inheritance

Constructors

OAuth2InvalidResponseException(String message)
Creates a new OAuth2InvalidResponseException object
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
A human-readable error message.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited