OAuth2PkceServerConfig class

Configuration for OAuth2 token exchange (server-side).

Constructors

OAuth2PkceServerConfig({required Uri tokenEndpointUrl, required String clientId, required String clientSecret, required ParseTokenResponse parseTokenResponse, String clientIdKey = 'client_id', String clientSecretKey = 'client_secret', OAuth2CredentialsLocation credentialsLocation = OAuth2CredentialsLocation.header, Map<String, String> tokenRequestHeaders = const {'Accept' : 'application/json', 'Content-Type' : 'application/x-www-form-urlencoded'}, Map<String, dynamic> tokenRequestParams = const {}})
Create a new server config for OAuth2 PKCE.
const

Properties

clientId → String
OAuth2 client ID.
final
clientIdKey → String
Request body parameter name for client ID.
final
clientSecret → String
OAuth2 client secret (keep secure).
final
clientSecretKey → String
Request body parameter name for client secret.
final
credentialsLocation → OAuth2CredentialsLocation
Where to send credentials in token requests.
final
hashCode → int
The hash code for this object.
no setterinherited
parseTokenResponse → ParseTokenResponse
Callback to parse the token response from the provider.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenEndpointUrl → Uri
Token endpoint URL for exchanging authorization codes.
final
tokenRequestHeaders → Map<String, String>
HTTP headers for token requests.
final
tokenRequestParams → Map<String, dynamic>
Extra parameters for token requests.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited