PasswordNotFoundException class final

Thrown when a requested password is missing from configuration.

Implemented types

Constructors

PasswordNotFoundException(String key)
Creates an exception indicating the missing password key.

Properties

envVarName → String
The name of the environment variable that is missing.
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → String
The password identifier that could not be found.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited