PreBuiltIdpBuilder<T extends IdentityProvider> class

A builder that returns a pre-built identity provider.

Use this builder if you have a provider built from outside of the Serverpod authentication framework.

Inheritance

Constructors

PreBuiltIdpBuilder(T idp)
Creates a new PreBuiltIdpBuilder instance.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
idp → T
The pre-built identity provider.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) → T
Builds a new instance of the identity provider.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited