countAttempts abstract method
Counts attempts for key within the configured window, or all time.
Implementation
Future<int> countAttempts(
final Session session, {
required final String key,
final Transaction? transaction,
});
Counts attempts for key within the configured window, or all time.
Future<int> countAttempts(
final Session session, {
required final String key,
final Transaction? transaction,
});