copyWith abstract method
Returns a shallow copy of this RefreshTokenExpiredException with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
RefreshTokenExpiredException copyWith();
Returns a shallow copy of this RefreshTokenExpiredException with some or all fields replaced by the given arguments.
@_is.useResult
RefreshTokenExpiredException copyWith();