copyWith abstract method
Returns a shallow copy of this RefreshTokenInvalidSecretException with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
RefreshTokenInvalidSecretException copyWith();
Returns a shallow copy of this RefreshTokenInvalidSecretException with some or all fields replaced by the given arguments.
@_is.useResult
RefreshTokenInvalidSecretException copyWith();