copyWith abstract method
Returns a shallow copy of this RefreshTokenMalformedException with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
RefreshTokenMalformedException copyWith();
Returns a shallow copy of this RefreshTokenMalformedException with some or all fields replaced by the given arguments.
@_is.useResult
RefreshTokenMalformedException copyWith();