copyWith abstract method
Returns a shallow copy of this RefreshTokenNotFoundException with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
RefreshTokenNotFoundException copyWith();
Returns a shallow copy of this RefreshTokenNotFoundException with some or all fields replaced by the given arguments.
@_is.useResult
RefreshTokenNotFoundException copyWith();