delete method
Future<List<RefreshToken> >
delete(
- DatabaseSession session,
- List<
RefreshToken> rows, { - OrderByBuilder<
RefreshTokenTable> ? orderBy, - @Deprecated('Use desc() on the orderBy column instead.') bool orderDescending = false,
- OrderByListBuilder<
RefreshTokenTable> ? orderByList, - Transaction? transaction,
- bool noReturn = false,
Deletes all RefreshTokens in the list and returns the deleted rows.
To specify the order of the returned rows use orderBy or orderByList
when sorting by multiple columns.
This is an atomic operation, meaning that if one of the rows fail to be deleted, none of the rows will be deleted.
If noReturn is set to true, the deleted rows are not read back from
the database and an empty list is returned. This avoids the overhead of
transferring and deserializing the rows when the result is not needed.
Implementation
Future<List<RefreshToken>> delete(
_i1.DatabaseSession session,
List<RefreshToken> rows, {
_i1.OrderByBuilder<RefreshTokenTable>? orderBy,
@Deprecated('Use desc() on the orderBy column instead.')
bool orderDescending = false,
_i1.OrderByListBuilder<RefreshTokenTable>? orderByList,
_i1.Transaction? transaction,
bool noReturn = false,
}) async {
return session.db.delete<RefreshToken>(
rows,
orderBy: orderBy?.call(RefreshToken.t),
orderByList: orderByList?.call(RefreshToken.t),
orderDescending: // ignore: deprecated_member_use
orderDescending,
transaction: transaction,
noReturn: noReturn,
);
}