RefreshTokenTable class

Constructors

RefreshTokenTable({TableRelation? tableRelation})

Properties

authUser → AuthUserTable
no setter
authUserId ↔ ColumnUuid
latefinal
columns → List<Column>
List of Column used by the table.
no setter
createdAt ↔ ColumnDateTime
The time when the first refresh token was created.
latefinal
extraClaims ↔ ColumnString
Extra claims to be added to each access token created for this refresh token.
latefinal
fixedSecret ↔ ColumnByteData
The fixed part of the secret.
latefinal
hasColumnMapping → bool
Cached flag indicating whether any columns have explicit column names that differ from their field names. Computed lazily on first access.
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<UuidValue?>
The database id.
latefinalinherited
lastUpdatedAt ↔ ColumnDateTime
The time when the rotatingSecretHash was last updated.
latefinal
managedColumns → List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
method ↔ ColumnString
The method through which this token was created.
latefinal
queryPrefix → String
Query prefix for Columns of the table.
no setterinherited
quotedTableName → String
tableName quoted for the current dialect. Prefer it over tableName in raw SQL, since dialects quote schemas differently.
no setterinherited
rotatingSecretHash ↔ ColumnString
The most recent rotating secret associated with this refresh token.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
Schema part of tableName, or null when the name is unqualified.
latefinalinherited
scopeNames ↔ ColumnSerializable<Set<String>>
The scopes given to this session.
latefinal
tableName → String
Name of the table as used in the database, optionally qualified as schema.table.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited
unqualifiedTableName → String
tableName with the schema removed.
latefinalinherited
updateTable ↔ RefreshTokenUpdateTable
latefinal

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited