SecretKey class

For HMAC algorithms

Constructors

SecretKey(String key, {bool isBase64Encoded = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isBase64Encoded ↔ bool
getter/setter pair
key ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJWK({String? keyID, HMACAlgorithm? algorithm}) → Map<String, dynamic>
Convert the key to a JWK JSON object representation
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited