id property
The id column of the row. Can be null if this row is not yet stored in the database.
Implementation
@override
_is.UuidValue? id;
The id column of the row. Can be null if this row is not yet stored in the database.
@override
_is.UuidValue? id;