ServerSideSessionRepository class
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<ServerSideSessionTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<ServerSideSession> rows, {Transaction? transaction})
→ Future<List<ServerSideSession>>
-
Deletes all ServerSideSessions in the list and returns the deleted rows.
This is an atomic operation, meaning that if one of the rows fail to
be deleted, none of the rows will be deleted.
-
deleteRow(DatabaseSession session, ServerSideSession row, {Transaction? transaction})
→ Future<ServerSideSession>
-
Deletes a single ServerSideSession.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<ServerSideSessionTable> where, Transaction? transaction})
→ Future<List<ServerSideSession>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<ServerSideSessionTable>? where, int? limit, int? offset, OrderByBuilder<ServerSideSessionTable>? orderBy, bool orderDescending = false, OrderByListBuilder<ServerSideSessionTable>? orderByList, Transaction? transaction, ServerSideSessionInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<ServerSideSession>>
-
Returns a list of ServerSideSessions matching the given query parameters.
-
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, ServerSideSessionInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<ServerSideSession?>
-
Finds a single ServerSideSession by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<ServerSideSessionTable>? where, int? offset, OrderByBuilder<ServerSideSessionTable>? orderBy, bool orderDescending = false, OrderByListBuilder<ServerSideSessionTable>? orderByList, Transaction? transaction, ServerSideSessionInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<ServerSideSession?>
-
Returns the first matching ServerSideSession matching the given query parameters.
-
insert(DatabaseSession session, List<ServerSideSession> rows, {Transaction? transaction, bool ignoreConflicts = false})
→ Future<List<ServerSideSession>>
-
Inserts all ServerSideSessions in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, ServerSideSession row, {Transaction? transaction})
→ Future<ServerSideSession>
-
Inserts a single ServerSideSession and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<ServerSideSessionTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on ServerSideSession rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<ServerSideSession> rows, {ColumnSelections<ServerSideSessionTable>? columns, Transaction? transaction})
→ Future<List<ServerSideSession>>
-
Updates all ServerSideSessions in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<ServerSideSessionUpdateTable> columnValues, Transaction? transaction})
→ Future<ServerSideSession?>
-
Updates a single ServerSideSession by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, ServerSideSession row, {ColumnSelections<ServerSideSessionTable>? columns, Transaction? transaction})
→ Future<ServerSideSession>
-
Updates a single ServerSideSession. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<ServerSideSessionUpdateTable> columnValues, required WhereExpressionBuilder<ServerSideSessionTable> where, int? limit, int? offset, OrderByBuilder<ServerSideSessionTable>? orderBy, OrderByListBuilder<ServerSideSessionTable>? orderByList, bool orderDescending = false, Transaction? transaction})
→ Future<List<ServerSideSession>>
-
Updates all ServerSideSessions matching the
where expression with the specified columnValues.
Returns the list of updated rows.