ServerSideSessionTable class

Constructors

ServerSideSessionTable({TableRelation? tableRelation})

Properties

authUser → AuthUserTable
no setter
authUserId ↔ ColumnUuid
latefinal
columns → List<Column>
List of Column used by the table.
no setter
createdAt ↔ ColumnDateTime
The time when this session was created.
latefinal
expireAfterUnusedFor ↔ ColumnDuration
The maximum duration this session can go unused.
latefinal
expiresAt ↔ ColumnDateTime
The time after which this session can not be used anymore.
latefinal
hasColumnMapping → bool
Cached flag indicating whether any columns have explicit column names that differ from their field names. Computed lazily on first access.
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<UuidValue?>
The database id.
latefinalinherited
lastUsedAt ↔ ColumnDateTime
The time when this access session was last used.
latefinal
managedColumns → List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
method ↔ ColumnString
The method through which this session was created.
latefinal
queryPrefix → String
Query prefix for Columns of the table.
no setterinherited
quotedTableName → String
tableName quoted for the current dialect. Prefer it over tableName in raw SQL, since dialects quote schemas differently.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
Schema part of tableName, or null when the name is unqualified.
latefinalinherited
scopeNames ↔ ColumnSerializable<Set<String>>
The scopes this session provides access to.
latefinal
sessionKeyHash ↔ ColumnByteData
Hashed version of the session key.
latefinal
sessionKeySalt ↔ ColumnByteData
The salt used for computing the sessionKeyHash.
latefinal
tableName → String
Name of the table as used in the database, optionally qualified as schema.table.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited
unqualifiedTableName → String
tableName with the schema removed.
latefinalinherited
updateTable ↔ ServerSideSessionUpdateTable
latefinal

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited