ServerSideSessionsConfig class

Configuration options for the session module.

Implemented types

Constructors

ServerSideSessionsConfig({required String sessionKeyHashPepper, List<String> fallbackSessionKeyHashPeppers = const [], int sessionKeySecretLength = 32, int sessionKeyHashSaltLength = 16, Duration? defaultSessionLifetime, Duration? defaultSessionInactivityTimeout, Future<void> onSessionCreated(Session session, {required UuidValue authUserId, required UuidValue serverSideSessionId, required Transaction? transaction})?})
Create a new user session configuration.

Properties

defaultSessionInactivityTimeout → Duration?
Default inactivity timeout for sessions.
final
defaultSessionLifetime → Duration?
Default absolute expiration time for sessions.
final
fallbackSessionKeyHashPeppers → List<String>
Fallback peppers for validating session keys created with previous peppers.
final
hashCode → int
The hash code for this object.
no setterinherited
onSessionCreated → Future<void> Function(Session session, {required UuidValue authUserId, required UuidValue serverSideSessionId, required Transaction? transaction})?
Called when a server side session has been created.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionKeyHashPepper → String
The pepper used for hashing authentication session keys.
final
sessionKeyHashSaltLength → int
Length of the salt used for the session key hash.
final
sessionKeySecretLength → int
Length of the session key secret (which is only stored on the client).
final

Methods

build({required AuthUsers authUsers}) → ServerSideSessionsTokenManager
Builds a new instance of the token manager.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited