ServerSideSessionsConfigFromPasswords class

Creates a new ServerSideSessionsConfig from keys on the passwords.yaml file.

This constructor requires that a Serverpod instance has already been initialized.

Inheritance

Constructors

ServerSideSessionsConfigFromPasswords({List<String> fallbackSessionKeyHashPeppers = const [], int sessionKeySecretLength = 32, int sessionKeyHashSaltLength = 16, Duration? defaultSessionLifetime, Duration? defaultSessionInactivityTimeout, Future<void> onSessionCreated(Session session, {required UuidValue authUserId, required UuidValue serverSideSessionId, required Transaction? transaction})?})
Creates a new ServerSideSessionsConfigFromPasswords instance.

Properties

defaultSessionInactivityTimeout → Duration?
Default inactivity timeout for sessions.
finalinherited
defaultSessionLifetime → Duration?
Default absolute expiration time for sessions.
finalinherited
fallbackSessionKeyHashPeppers → List<String>
Fallback peppers for validating session keys created with previous peppers.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
onSessionCreated → Future<void> Function(Session session, {required UuidValue authUserId, required UuidValue serverSideSessionId, required Transaction? transaction})?
Called when a server side session has been created.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionKeyHashPepper → String
The pepper used for hashing authentication session keys.
finalinherited
sessionKeyHashSaltLength → int
Length of the salt used for the session key hash.
finalinherited
sessionKeySecretLength → int
Length of the session key secret (which is only stored on the client).
finalinherited

Methods

build({required AuthUsers authUsers}) → ServerSideSessionsTokenManager
Builds a new instance of the token manager.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited