ServerSideSessionsTokenManager class

Token manager adapter for ServerSideSessions.

This class is used to bridge the gap between the ServerSideSessions and the TokenManager interface. It delegates all operations to the ServerSideSessions instance.

Inheritance

Constructors

ServerSideSessionsTokenManager({required ServerSideSessionsConfig config, AuthUsers authUsers = const AuthUsers()})
Creates a new ServerSideSessionsTokenManager instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverSideSessions ServerSideSessions
The ServerSideSessions instance.
final

Methods

createToken(Session session, {required UuidValue authUserId, required String method, Set<Scope>? scopes, Transaction? transaction}) Future<AuthSuccess>
Creates a new authentication token for the specified user with the given authentication method and optional scopes.
override
issueToken(Session session, {required UuidValue authUserId, required String method, Set<Scope>? scopes, Transaction? transaction}) Future<AuthSuccess>
Issues an authentication token for authUserId and delivers it according to the request.
inherited
listTokens(Session session, {required UuidValue? authUserId, String? method, String? tokenIssuer, Transaction? transaction}) Future<List<TokenInfo>>
Lists all TokenInfos matching the given criteria.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshCookiePath(Session session) String?
The cookie Path for a cookie-delivered refresh token, or null for the configured auth cookie path.
inherited
refreshTokenExpiresAt() DateTime?
The expiry of a cookie-delivered refresh token, or null for a browser session cookie.
inherited
revokeAllTokens(Session session, {required UuidValue? authUserId, Transaction? transaction, String? method, String? tokenIssuer}) Future<void>
Revokes all tokens matching the given criteria.
override
revokeToken(Session session, {required String tokenId, Transaction? transaction, String? tokenIssuer}) Future<void>
Revokes a specific token by its ID.
override
toString() String
A string representation of this object.
inherited
validateToken(Session session, String token) Future<AuthenticationInfo?>
Validates an authentication token and returns the associated authentication information.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

tokenIssuerName String
The name of the token issuer.
no setter