copyWith abstract method
Returns a shallow copy of this SignInWhileAuthenticatedException with some or all fields replaced by the given arguments.
Implementation
@_is.useResult
SignInWhileAuthenticatedException copyWith();
Returns a shallow copy of this SignInWhileAuthenticatedException with some or all fields replaced by the given arguments.
@_is.useResult
SignInWhileAuthenticatedException copyWith();