TokenInfo class

Information about an authentication token.

Constructors

TokenInfo({required String userId, required String tokenIssuer, required String tokenId, required Set<Scope> scopes, required String method})
Creates a new TokenInfo instance.

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
The authentication method used to create this token.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → Set<Scope>
The scopes granted by this token.
final
tokenId → String
The unique identifier of this token.
final
tokenIssuer → String
The name of the token issuer that issued this token.
final
userId → String
The ID of the user this token belongs to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited