UserImageFromUrl class final

User image source from a URL.

Inheritance

Constructors

UserImageFromUrl(Uri url)
Creates a new UserImageFromUrl instance.
UserImageFromUrl.parse(String url)
Creates a new UserImageFromUrl instance by parsing the given url string.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → Uri
The URL to fetch the image from.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited