UserProfileConfig class

Configuration options for the user profile module.

Constructors

UserProfileConfig({int userImageSize = 256, Duration userInfoCacheLifetime = const Duration(minutes: 1), UserImageGenerator userImageGenerator = defaultUserImageGenerator, UserProfileImageType userImageFormat = UserProfileImageType.jpg, int userImageQuality = 70, BeforeUserProfileCreatedHandler? onBeforeUserProfileCreated, AfterUserProfileCreatedHandler? onAfterUserProfileCreated, BeforeUserProfileUpdatedHandler? onBeforeUserProfileUpdated, AfterUserProfileUpdatedHandler? onAfterUserProfileUpdated, FutureOr<Uint8List> imageFetchFunc(Uri url) = _defaultImageFetch})
Create a new user profile configuration.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageFetchFunc → FutureOr<Uint8List> Function(Uri url)
The function used to fetch profile image by URL.
final
onAfterUserProfileCreated → AfterUserProfileCreatedHandler?
Called after a user profile has been created.
final
onAfterUserProfileUpdated → AfterUserProfileUpdatedHandler?
Called whenever a user profile has been updated.
final
onBeforeUserProfileCreated → BeforeUserProfileCreatedHandler?
Called when a user profile is about to be created.
final
onBeforeUserProfileUpdated → BeforeUserProfileUpdatedHandler?
Called before a user profile is about to be updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userImageFormat → UserProfileImageType
The format used to store user images. Defaults to JPG images.
final
userImageGenerator → UserImageGenerator
Generator used to produce default user images. By default a generator that mimics Google's default avatars is used.
final
userImageQuality → int
The quality setting for images if JPG format is used.
final
userImageSize → int
The size of user images.
final
userInfoCacheLifetime → Duration
The duration which user infos are cached locally in the server.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited