UserProfileImageRepository class
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<UserProfileImageTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<UserProfileImage> rows, {Transaction? transaction})
→ Future<List<UserProfileImage>>
-
Deletes all UserProfileImages in the list and returns the deleted rows.
This is an atomic operation, meaning that if one of the rows fail to
be deleted, none of the rows will be deleted.
-
deleteRow(DatabaseSession session, UserProfileImage row, {Transaction? transaction})
→ Future<UserProfileImage>
-
Deletes a single UserProfileImage.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<UserProfileImageTable> where, Transaction? transaction})
→ Future<List<UserProfileImage>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<UserProfileImageTable>? where, int? limit, int? offset, OrderByBuilder<UserProfileImageTable>? orderBy, bool orderDescending = false, OrderByListBuilder<UserProfileImageTable>? orderByList, Transaction? transaction, UserProfileImageInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<UserProfileImage>>
-
Returns a list of UserProfileImages matching the given query parameters.
-
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, UserProfileImageInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<UserProfileImage?>
-
Finds a single UserProfileImage by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<UserProfileImageTable>? where, int? offset, OrderByBuilder<UserProfileImageTable>? orderBy, bool orderDescending = false, OrderByListBuilder<UserProfileImageTable>? orderByList, Transaction? transaction, UserProfileImageInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<UserProfileImage?>
-
Returns the first matching UserProfileImage matching the given query parameters.
-
insert(DatabaseSession session, List<UserProfileImage> rows, {Transaction? transaction, bool ignoreConflicts = false})
→ Future<List<UserProfileImage>>
-
Inserts all UserProfileImages in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, UserProfileImage row, {Transaction? transaction})
→ Future<UserProfileImage>
-
Inserts a single UserProfileImage and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<UserProfileImageTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on UserProfileImage rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<UserProfileImage> rows, {ColumnSelections<UserProfileImageTable>? columns, Transaction? transaction})
→ Future<List<UserProfileImage>>
-
Updates all UserProfileImages in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<UserProfileImageUpdateTable> columnValues, Transaction? transaction})
→ Future<UserProfileImage?>
-
Updates a single UserProfileImage by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, UserProfileImage row, {ColumnSelections<UserProfileImageTable>? columns, Transaction? transaction})
→ Future<UserProfileImage>
-
Updates a single UserProfileImage. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<UserProfileImageUpdateTable> columnValues, required WhereExpressionBuilder<UserProfileImageTable> where, int? limit, int? offset, OrderByBuilder<UserProfileImageTable>? orderBy, OrderByListBuilder<UserProfileImageTable>? orderByList, bool orderDescending = false, Transaction? transaction})
→ Future<List<UserProfileImage>>
-
Updates all UserProfileImages matching the
where expression with the specified columnValues.
Returns the list of updated rows.