updateWhere method
Future<List<UserProfile> >
updateWhere(
- DatabaseSession session, {
- required ColumnValueListBuilder<
UserProfileUpdateTable> columnValues, - required WhereExpressionBuilder<
UserProfileTable> where, - int? limit,
- int? offset,
- OrderByBuilder<
UserProfileTable> ? orderBy, - OrderByListBuilder<
UserProfileTable> ? orderByList, - @Deprecated('Use desc() on the orderBy column instead.') bool orderDescending = false,
- Transaction? transaction,
- bool noReturn = false,
Updates all UserProfiles matching the where expression with the specified columnValues.
Returns the list of updated rows.
If noReturn is set to true, the updated rows are not read back from
the database and an empty list is returned. This avoids the overhead of
transferring and deserializing the rows when the result is not needed.
Implementation
Future<List<UserProfile>> updateWhere(
_i1.DatabaseSession session, {
required _i1.ColumnValueListBuilder<UserProfileUpdateTable> columnValues,
required _i1.WhereExpressionBuilder<UserProfileTable> where,
int? limit,
int? offset,
_i1.OrderByBuilder<UserProfileTable>? orderBy,
_i1.OrderByListBuilder<UserProfileTable>? orderByList,
@Deprecated('Use desc() on the orderBy column instead.')
bool orderDescending = false,
_i1.Transaction? transaction,
bool noReturn = false,
}) async {
return session.db.updateWhere<UserProfile>(
columnValues: columnValues(UserProfile.t.updateTable),
where: where(UserProfile.t),
limit: limit,
offset: offset,
orderBy: orderBy?.call(UserProfile.t),
orderByList: orderByList?.call(UserProfile.t),
orderDescending: // ignore: deprecated_member_use
orderDescending,
transaction: transaction,
noReturn: noReturn,
);
}