email property
ColumnString
email
latefinal
The verified email address of the user.
This should only be set by authentication providers that have checked ownership of this email for the user.
Stored in lower-case.
Implementation
late final _is.ColumnString email;