AnonymousIdpAccountCreationResult class

The result of the AnonymousIdpAccountCreationUtil.createAnonymousAccount operation.

Properties

authUserId → UuidValue
The ID of the new authentication user.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes Set<Scope>
The scopes of the new authentication user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited