login method

Future<AuthSuccess> login(
  1. Session session, {
  2. String? token,
})

Creates a new anonymous account and returns its session.

Invokes the AnonymousIdp.beforeAnonymousAccount callback if configured, which may prevent account creation if the endpoint is protected.

Implementation

Future<AuthSuccess> login(
  final Session session, {
  final String? token,
}) async {
  return anonymousIdp.login(session, token: token);
}