AnonymousIdpUtils class

Anonymous account management functions.

Constructors

AnonymousIdpUtils({required AnonymousIdpConfig config, AuthUsers authUsers = const AuthUsers()})
Creates a new instance of AnonymousIdpUtils.

Properties

config → AnonymousIdpConfig
Configuration for the anonymous identity provider.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAnonymousAccount(Session session, {Transaction? transaction}) → Future<AnonymousIdpAccountCreationResult>
Creates a new anonymous account.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited