providers/apple library
This library contains the Apple authentication provider for the Serverpod Idp module.
Classes
- AppleAccount
- A fully configured "Sign in with Apple"-based account to be used for logins.
- AppleIdp
- Main class for the Apple identity provider. The methods defined here are intended to be called from an endpoint.
- AppleIdpAdmin
- Collection of Apple-account admin methods.
- AppleIdpBaseEndpoint
- Endpoint for handling Sign in with Apple.
- AppleIdpConfig
- Configuration for the Apple identity provider.
- AppleIdpConfigFromPasswords
-
Creates a new AppleIdpConfig from keys on the
passwords.yamlfile. - AppleIdpUtils
- Utility functions for the Apple identity provider.
- AuthSuccess
- Response model representing a successful authentication result with all relevant authentication information.
Extensions
- AppleIdpConfigExtension on AppleIdpConfig
- Extension methods for AppleIdpConfig.
- AppleIdpConfigureRoutes on Serverpod
- Extension to configure AppleIdp routes on the web server.
- AppleIdpGetter on AuthServices
- Extension to get the AppleIdp instance from the AuthServices.
Typedefs
-
AfterAppleAccountCreatedFunction
= FutureOr<
void> Function(Session session, AuthUserModel authUser, AppleAccount appleAccount, {required Transaction? transaction}) -
Callback to be invoked after a new Apple account has been created and
linked to an auth user. The
sessionandtransactioncan be used to perform additional database operations. - AppleAccountDetails = ({String? email, String? firstName, bool? isPrivateEmail, bool? isVerifiedEmail, String? lastName, String userIdentifier})
- Details of the Apple account.
-
AppleAuthSuccess
= ({UuidValue appleAccountId, UuidValue authUserId, AppleAccountDetails details, bool newAccount, Set<
Scope> scopes}) - Details of a successful Apple-based authentication.