AfterAppleAccountCreatedFunction typedef

AfterAppleAccountCreatedFunction = FutureOr<void> Function(Session session, AuthUserModel authUser, AppleAccount appleAccount, {required Transaction? transaction})

Callback to be invoked after a new Apple account has been created and linked to an auth user. The session and transaction can be used to perform additional database operations.

Implementation

typedef AfterAppleAccountCreatedFunction =
    FutureOr<void> Function(
      Session session,
      AuthUserModel authUser,
      AppleAccount appleAccount, {
      required Transaction? transaction,
    });