AppleIdpConfig class

Configuration for the Apple identity provider.

Inheritance
Implementers
Available extensions

Constructors

AppleIdpConfig({required String serviceIdentifier, required String bundleIdentifier, required String redirectUri, required String teamId, required String keyId, required String key, String? androidPackageIdentifier, String? webRedirectUri, AfterAppleAccountCreatedFunction? onAfterAppleAccountCreated})
Creates a new Sign in with Apple configuration.
const

Properties

androidPackageIdentifier → String?
The Android package identifier for the app using Sign in with Apple.
final
bundleIdentifier → String
The bundle ID of the Apple-native app using Sign in with Apple.
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
The secret contents of the private key file received once from Apple.
final
keyId → String
The ID of the key associated with the Sign in with Apple service.
final
onAfterAppleAccountCreated → AfterAppleAccountCreatedFunction?
Callback to be invoked after a new Apple account has been created and linked to an auth user.
final
redirectUri → String
The redirect URL used for 3rd party platforms, e.g. Android.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceIdentifier → String
The service identifier for the Sign in with Apple project.
final
teamId → String
The team identifier of the parent Apple Developer account.
final
type → Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited
webRedirectUri → String?
The web app URL to redirect to after receiving Apple's web callback.
final

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) → AppleIdp
Builds a new instance of the identity provider.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSignInWithAppleConfiguration() → SignInWithAppleConfiguration

Available on AppleIdpConfig, provided by the AppleIdpConfigExtension extension

Converts the AppleIdpConfig to a SignInWithAppleConfiguration.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited