AppleIdpConfigFromPasswords class

Creates a new AppleIdpConfig from keys on the passwords.yaml file.

This constructor requires that a Serverpod instance has already been initialized.

Inheritance
Available extensions

Constructors

AppleIdpConfigFromPasswords()
Creates a new AppleIdpConfigFromPasswords instance.

Properties

androidPackageIdentifier String?
The Android package identifier for the app using Sign in with Apple.
finalinherited
bundleIdentifier String
The bundle ID of the Apple-native app using Sign in with Apple.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key String
The secret contents of the private key file received once from Apple.
finalinherited
keyId String
The ID of the key associated with the Sign in with Apple service.
finalinherited
redirectUri String
The redirect URL used for 3rd party platforms, e.g. Android.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceIdentifier String
The service identifier for the Sign in with Apple project.
finalinherited
teamId String
The team identifier of the parent Apple Developer account.
finalinherited
type Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited
webRedirectUri String?
The web app URL to redirect to after receiving Apple's web callback.
finalinherited

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) AppleIdp
Builds a new instance of the identity provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSignInWithAppleConfiguration() → SignInWithAppleConfiguration

Available on AppleIdpConfig, provided by the AppleIdpConfigExtension extension

Converts the AppleIdpConfig to a SignInWithAppleConfiguration.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited