method property
String
get
method
The method used when authenticating with the Apple identity provider.
Implementation
String get method => 'apple';
The method used when authenticating with the Apple identity provider.
String get method => 'apple';