EmailIdpAccountCreationUtilsConfig class

Configuration for the EmailIdpAccountCreationUtil class.

Constructors

EmailIdpAccountCreationUtilsConfig({required PasswordValidationFunction passwordValidationFunction, required String registrationVerificationCodeGenerator(), required Duration registrationVerificationCodeLifetime, required int registrationVerificationCodeAllowedAttempts, required SendRegistrationVerificationCodeFunction? sendRegistrationVerificationCode, required AfterAccountCreatedFunction? onAfterAccountCreated})
Creates a new EmailIdpAccountCreationUtilsConfig instance.
EmailIdpAccountCreationUtilsConfig.fromEmailIdpConfig(EmailIdpConfig config)
Creates a new EmailIdpAccountCreationUtilsConfig instance from an EmailIdpConfig instance.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
onAfterAccountCreated → AfterAccountCreatedFunction?
Callback to be invoked after a new email account has been created.
final
passwordValidationFunction → PasswordValidationFunction
Function for validating the password.
final
registrationVerificationCodeAllowedAttempts → int
The number of allowed attempts to verify the registration code.
final
registrationVerificationCodeGenerator → String Function()
Function for generating the registration verification code.
final
registrationVerificationCodeLifetime → Duration
The lifetime of the registration verification code.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendRegistrationVerificationCode → SendRegistrationVerificationCodeFunction?
Function for sending the registration verification code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited