EmailIdpPasswordResetUtilsConfig class

Configuration options for the EmailIdpPasswordResetUtil class.

Constructors

EmailIdpPasswordResetUtilsConfig({required PasswordValidationFunction passwordValidationFunction, required int passwordResetVerificationCodeAllowedAttempts, required Duration passwordResetVerificationCodeLifetime, required OnPasswordResetCompletedFunction? onPasswordResetCompleted, required RateLimit maxPasswordResetAttempts, required String passwordResetVerificationCodeGenerator(), required SendPasswordResetVerificationCodeFunction? sendPasswordResetVerificationCode})
Creates a new EmailIdpPasswordResetUtilsConfig instance.
EmailIdpPasswordResetUtilsConfig.fromEmailIdpConfig(EmailIdpConfig config)
Creates a new EmailIdpPasswordResetUtilsConfig instance from an EmailIdpConfig instance.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxPasswordResetAttempts → RateLimit
The maximum number of password reset attempts allowed within the timeframe.
final
onPasswordResetCompleted → OnPasswordResetCompletedFunction?
Callback to be invoked after a password reset is successfully completed.
final
passwordResetVerificationCodeAllowedAttempts → int
The number of allowed attempts to verify the password reset code.
final
passwordResetVerificationCodeGenerator → String Function()
Function for generating the password reset verification code.
final
passwordResetVerificationCodeLifetime → Duration
The lifetime of the password reset verification code.
final
passwordValidationFunction → PasswordValidationFunction
Function for validating the password.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendPasswordResetVerificationCode → SendPasswordResetVerificationCodeFunction?
Callback to be invoked for sending out the password reset verification code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited