passwordReset property

EmailIdpPasswordResetUtil passwordReset
latefinal

Class for handling password reset operations in the email account module.

The main entry point is the startPasswordReset method, which can be used to start a password reset process.

This class also contains utility functions for administration tasks, such as deleting expired password reset requests and password reset attempts.

Implementation

late final EmailIdpPasswordResetUtil passwordReset;