defaultTimeout constant
Duration
const defaultTimeout
The default maximum time to wait for the service to respond.
Implementation
static const defaultTimeout = Duration(seconds: 30);
The default maximum time to wait for the service to respond.
static const defaultTimeout = Duration(seconds: 30);