providers/facebook library

This library contains the Facebook authentication provider for the Serverpod Idp module.

Classes

AuthSuccess
Response model representing a successful authentication result with all relevant authentication information.
FacebookAccount
A fully configured Facebook account to be used for logins.\
FacebookIdp
Main class for the Facebook identity provider. The methods defined here are intended to be called from an endpoint.
FacebookIdpAdmin
Collection of Facebook-account admin methods.
FacebookIdpBaseEndpoint
Base endpoint for Facebook Account-based authentication.
FacebookIdpConfig
Configuration for the Facebook identity provider.
FacebookIdpConfigFromPasswords
Creates a new FacebookIdpConfig from keys on the passwords.yaml file.
FacebookIdpUtils
Utility functions for the Facebook identity provider.

Extensions

FacebookIdpGetter on AuthServices
Extension to get the FacebookIdp instance from the AuthServices.

Typedefs

FacebookAccountDetails = ({String? email, String? firstName, String? fullName, Uri? image, String? lastName, String userIdentifier})
Details of the Facebook Account.
FacebookAccountDetailsValidation = void Function(FacebookAccountDetails accountDetails)
Function to be called to check whether a Facebook account details match the requirements during registration.
FacebookAuthSuccess = ({UuidValue authUserId, FacebookAccountDetails details, UuidValue facebookAccountId, bool newAccount, Set<Scope> scopes})
Result of a successful authentication using Facebook as identity provider.
GetExtraFacebookInfoCallback = Future<void> Function(Session session, {required String accessToken, required FacebookAccountDetails accountDetails, required Transaction? transaction})
Function to be called to extract additional information from Facebook API using the access token. The session and transaction can be used to store additional information in the database.

Exceptions / Errors

FacebookAccessTokenVerificationException
Exception to be thrown if the Facebook access token verification fails.
FacebookUserInfoMissingDataException
Exception thrown when Facebook user information is missing required data.