method constant
String
const method
The method used when authenticating with the Facebook identity provider.
Implementation
static const String method = 'facebook';
The method used when authenticating with the Facebook identity provider.
static const String method = 'facebook';