facebookAccountDetailsValidation property
Validation function for Facebook account details.
This function should throw an exception if the account details do not match the requirements. If the function returns normally, the account is considered valid.
It can be used to enforce additional requirements on the Facebook account details before allowing the user to sign in.
To avoid blocking real users with private profiles from signing in, adjust your validation function with care.
Implementation
final FacebookAccountDetailsValidation facebookAccountDetailsValidation;