FacebookIdpConfigFromPasswords class

Creates a new FacebookIdpConfig from keys on the passwords.yaml file.

This constructor requires that a Serverpod instance has already been initialized.

The following keys must be present in the passwords.yaml file:

  • facebookAppId: The app ID from your Facebook Developer app
  • facebookAppSecret: The app secret from your Facebook Developer app

Example passwords.yaml:

facebookAppId: 'your-app-id'
facebookAppSecret: 'your-app-secret'
Inheritance

Constructors

FacebookIdpConfigFromPasswords({FacebookAccountDetailsValidation facebookAccountDetailsValidation = validateFacebookAccountDetails, GetExtraFacebookInfoCallback? getExtraFacebookInfoCallback})
Creates a new FacebookIdpConfigFromPasswords instance.

Properties

appId String
The app ID from your Facebook Developer app.
finalinherited
appSecret String
The app secret from your Facebook Developer app.
finalinherited
facebookAccountDetailsValidation FacebookAccountDetailsValidation
Validation function for Facebook account details.
finalinherited
getExtraFacebookInfoCallback GetExtraFacebookInfoCallback?
Callback that can be used with the access token to extract additional information from Facebook Graph API.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) FacebookIdp
Builds a new instance of the identity provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited