FirebaseIdp class
Main class for the Firebase identity provider.
The methods defined here are intended to be called from an endpoint.
The admin property provides access to FirebaseIdpAdmin, which contains
admin-related methods for managing Firebase-backed accounts.
The utils property provides access to FirebaseIdpUtils, which contains
utility methods for working with Firebase-backed accounts. These can be used
to implement custom authentication flows if needed.
If you would like to modify the authentication flow, consider creating custom implementations of the relevant methods.
- Implemented types
Constructors
- FirebaseIdp(FirebaseIdpConfig config, {required TokenIssuer tokenIssuer, AuthUsers authUsers = const AuthUsers(), UserProfiles userProfiles = const UserProfiles()})
-
Creates a new instance of FirebaseIdp.
factory
Properties
- admin → FirebaseIdpAdmin
-
Admin operations to work with Firebase-backed accounts.
final
- config → FirebaseIdpConfig
-
The configuration for the Firebase identity provider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
The method used when authenticating with the Firebase identity provider.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- utils → FirebaseIdpUtils
-
Utility functions for the Firebase identity provider.
final
Methods
-
hasAccount(
Session session) → Future< bool> - Determines whether the current session has an associated Firebase account.
-
login(
Session session, {required String idToken, Transaction? transaction}) → Future< AuthSuccess> - Validates a Firebase ID token and either logs in the associated user or creates a new user account if the Firebase account ID is not yet known.
-
mergeAuthUsers(
Session session, {required UuidValue userToKeepId, required UuidValue userToRemoveId, required Transaction transaction}) → Future< void> -
Migrates all FirebaseAccounts from
userToRemoveIdtouserToKeepId.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited