FirebaseIdpAdmin class

Admin operations for the Firebase identity provider.

These methods are intended for administrative use to manage Firebase-backed accounts.

Constructors

FirebaseIdpAdmin({required FirebaseIdpUtils utils})
Creates a new instance of FirebaseIdpAdmin.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
utils → FirebaseIdpUtils
Utility functions for the Firebase identity provider.
final

Methods

deleteFirebaseAccount(Session session, {required String userIdentifier, Transaction? transaction}) → Future<FirebaseAccount?>
Deletes a Firebase account by user identifier (Firebase UID).
deleteFirebaseAccountByAuthUserId(Session session, {required UuidValue authUserId, Transaction? transaction}) → Future<FirebaseAccount?>
Deletes a Firebase account by auth user ID.
fetchAccountDetails(Session session, {required String idToken}) → Future<FirebaseAccountDetails>
Returns the account details for the given idToken.
findAccountByAuthUserId(Session session, {required UuidValue authUserId, Transaction? transaction}) → Future<FirebaseAccount?>
Finds a Firebase account by auth user ID.
findAccountByEmail(Session session, {required String email, Transaction? transaction}) → Future<FirebaseAccount?>
Finds a Firebase account by email.
linkFirebaseAuthentication(Session session, {required UuidValue authUserId, required FirebaseAccountDetails accountDetails, Transaction? transaction}) → Future<FirebaseAccount>
Adds a Firebase authentication to the given authUserId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

findUserByFirebaseUserId(Session session, {required String userIdentifier, Transaction? transaction}) → Future<UuidValue?>
Returns the AuthUser id for the Firebase user id, if any.