FirebaseIdpConfig class

Configuration for the Firebase identity provider.

Inheritance
Implementers

Constructors

FirebaseIdpConfig({required FirebaseServiceAccountCredentials credentials, FirebaseAccountDetailsValidation firebaseAccountDetailsValidation = validateFirebaseAccountDetails, AfterFirebaseAccountCreatedFunction? onAfterFirebaseAccountCreated, Duration clockSkewTolerance = defaultIdTokenClockSkewTolerance})
Creates a new instance of FirebaseIdpConfig.
const

Properties

clockSkewTolerance → Duration
Tolerance for clock skew when validating Firebase ID token timestamps.
final
credentials → FirebaseServiceAccountCredentials
The Firebase service account credentials.
final
firebaseAccountDetailsValidation → FirebaseAccountDetailsValidation
Validation function for Firebase account details.
final
hashCode → int
The hash code for this object.
no setterinherited
onAfterFirebaseAccountCreated → AfterFirebaseAccountCreatedFunction?
Callback to be invoked after a new Firebase account has been created and linked to an auth user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) → FirebaseIdp
Builds a new instance of the identity provider.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

requireVerifiedEmail(FirebaseAccountDetails accountDetails) → void
Validation function that requires the email to be verified when present.
validateFirebaseAccountDetails(FirebaseAccountDetails accountDetails) → void
Default validation function for extracted Firebase account details.