FirebaseIdpConfigFromPasswords class

Creates a new FirebaseIdpConfig from keys on the passwords.yaml file.

This constructor requires that a Serverpod instance has already been initialized.

The password key should be firebaseServiceAccountKey and contain the entire service account JSON as a string.

Inheritance

Constructors

FirebaseIdpConfigFromPasswords({FirebaseAccountDetailsValidation firebaseAccountDetailsValidation = validateFirebaseAccountDetails, AfterFirebaseAccountCreatedFunction? onAfterFirebaseAccountCreated, Duration clockSkewTolerance = defaultIdTokenClockSkewTolerance})
Creates a new FirebaseIdpConfigFromPasswords instance.

Properties

clockSkewTolerance → Duration
Tolerance for clock skew when validating Firebase ID token timestamps.
finalinherited
credentials → FirebaseServiceAccountCredentials
The Firebase service account credentials.
finalinherited
firebaseAccountDetailsValidation → FirebaseAccountDetailsValidation
Validation function for Firebase account details.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
onAfterFirebaseAccountCreated → AfterFirebaseAccountCreatedFunction?
Callback to be invoked after a new Firebase account has been created and linked to an auth user.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) → FirebaseIdp
Builds a new instance of the identity provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited