AfterGitHubAccountCreatedFunction typedef

AfterGitHubAccountCreatedFunction = FutureOr<void> Function(Session session, AuthUserModel authUser, GitHubAccount githubAccount, {required Transaction? transaction})

Callback to be invoked after a new GitHub account has been created and linked to an auth user. The session and transaction can be used to perform additional database operations.

Implementation

typedef AfterGitHubAccountCreatedFunction =
    FutureOr<void> Function(
      Session session,
      AuthUserModel authUser,
      GitHubAccount githubAccount, {
      required Transaction? transaction,
    });