onAfterGitHubAccountCreated property
Callback to be invoked after a new GitHub account has been created and linked to an auth user.
This can be used to perform additional setup tasks after the GitHub account has been created and linked.
Implementation
final AfterGitHubAccountCreatedFunction? onAfterGitHubAccountCreated;