GitHubIdpConfigFromPasswords class

Creates a new GitHubIdpConfig from keys on the passwords.yaml file.

This constructor requires that a Serverpod instance has already been initialized.

The following keys must be present in the passwords.yaml file:

  • githubClientId: The client ID from your GitHub OAuth App
  • githubClientSecret: The client secret from your GitHub OAuth App

Example passwords.yaml:

githubClientId: 'your-github-oauth-client-id'
githubClientSecret: 'your-github-oauth-client-secret'
Inheritance

Constructors

GitHubIdpConfigFromPasswords({GitHubAccountDetailsValidation githubAccountDetailsValidation = validateGitHubAccountDetails, GetExtraGitHubInfoCallback? getExtraGitHubInfoCallback, AfterGitHubAccountCreatedFunction? onAfterGitHubAccountCreated})
Creates a new GitHubIdpConfigFromPasswords instance.

Properties

clientId → String
The client ID from your GitHub OAuth App.
finalinherited
clientSecret → String
The client secret from your GitHub OAuth App.
finalinherited
getExtraGitHubInfoCallback → GetExtraGitHubInfoCallback?
Callback that can be used with the access token to extract additional information from GitHub.
finalinherited
githubAccountDetailsValidation → GitHubAccountDetailsValidation
Validation function for GitHub account details.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
oauth2Config ↔ OAuth2PkceServerConfig
OAuth2 PKCE server config for GitHub.
latefinalinherited
onAfterGitHubAccountCreated → AfterGitHubAccountCreatedFunction?
Callback to be invoked after a new GitHub account has been created and linked to an auth user.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) → GitHubIdp
Builds a new instance of the identity provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited