GoogleClientSecret class final

Contains information about the credentials for the server to access Google's APIs. The secrets are typically loaded from config/google_client_secret.json. The file can be downloaded from Google's cloud console.

Constructors

GoogleClientSecret.fromJson(Map<String, dynamic> json)
Creates a new instance of GoogleClientSecret from a JSON map. Expects the JSON to match the structure of the file downloaded from Google's cloud console.
factory
GoogleClientSecret.fromJsonFile(File file)
Creates a new instance of GoogleClientSecret from a JSON file. The file is expected to follow the format described in GoogleClientSecret.fromJson.
factory
GoogleClientSecret.fromJsonString(String jsonString)
Creates a new instance of GoogleClientSecret from a JSON string. The string is expected to follow the format described in GoogleClientSecret.fromJson.
factory

Properties

clientId → String
The client identifier.
final
clientSecret → String
The client secret.
final
hashCode → int
The hash code for this object.
no setterinherited
redirectUris → List<String>
List of redirect uris.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited