GoogleIdpConfig class

Configuration for the Google identity provider.

Inheritance
Implementers

Constructors

GoogleIdpConfig({required GoogleClientSecret clientSecret, GoogleAccountDetailsValidation googleAccountDetailsValidation = validateGoogleAccountDetails, GetExtraGoogleInfoCallback? getExtraGoogleInfoCallback, AfterGoogleAccountCreatedFunction? onAfterGoogleAccountCreated, Duration clockSkewTolerance = defaultIdTokenClockSkewTolerance})
Creates a new instance of GoogleIdpConfig.
const

Properties

clientSecret → GoogleClientSecret
The client secret used for the Google sign-in.
final
clockSkewTolerance → Duration
Tolerance for clock skew when validating Google ID token timestamps.
final
getExtraGoogleInfoCallback → GetExtraGoogleInfoCallback?
Callback that can be used with the access token to extract additional information from Google APIs.
final
googleAccountDetailsValidation → GoogleAccountDetailsValidation
Validation function for Google account details.
final
hashCode → int
The hash code for this object.
no setterinherited
oauth2PkceServerConfig → OAuth2PkceServerConfig
OAuth2 PKCE server configuration for the web sign-in flow.
no setter
onAfterGoogleAccountCreated → AfterGoogleAccountCreatedFunction?
Callback to be invoked after a new Google account has been created and linked to an auth user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) → GoogleIdp
Builds a new instance of the identity provider.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseTokenResponse(Map<String, dynamic> responseBody) → OAuth2PkceTokenResponse
Parses Google's OAuth2 token response.
validateGoogleAccountDetails(GoogleAccountDetails accountDetails) → void
Default validation function for extracted Google account details.