AfterMicrosoftAccountCreatedFunction typedef

AfterMicrosoftAccountCreatedFunction = FutureOr<void> Function(Session session, AuthUserModel authUser, MicrosoftAccount microsoftAccount, {required Transaction? transaction})

Callback to be invoked after a new Microsoft account has been created and linked to an auth user. The session and transaction can be used to perform additional database operations.

Implementation

typedef AfterMicrosoftAccountCreatedFunction =
    FutureOr<void> Function(
      Session session,
      AuthUserModel authUser,
      MicrosoftAccount microsoftAccount, {
      required Transaction? transaction,
    });