MicrosoftAccountDetails typedef
MicrosoftAccountDetails = ({String? email, Uint8List? imageBytes, String? name, String userIdentifier})
Details of the Microsoft Account.
All nullable fields are not guaranteed to be available from Microsoft's API, since the user may have a private email or limited profile information.
Implementation
typedef MicrosoftAccountDetails = ({
/// Microsoft's user identifier for this account.
String userIdentifier,
/// The email received from Microsoft (may be null if private).
String? email,
/// The user's name from Microsoft.
String? name,
/// The user's profile photo (only fetched if [MicrosoftIdpConfig.fetchProfilePhoto] is enabled).
Uint8List? imageBytes,
});