method constant
String
const method
The method used when authenticating with the Microsoft identity provider.
Implementation
static const String method = 'microsoft';
The method used when authenticating with the Microsoft identity provider.
static const String method = 'microsoft';