MicrosoftIdpConfig class

Configuration for the Microsoft identity provider.

Inheritance
Implementers

Constructors

MicrosoftIdpConfig({required String clientId, required String clientSecret, String tenant = 'common', String authorityHost = 'login.microsoftonline.com', bool fetchProfilePhoto = true, MicrosoftAccountDetailsValidation microsoftAccountDetailsValidation = validateMicrosoftAccountDetails, GetExtraMicrosoftInfoCallback? getExtraMicrosoftInfoCallback, AfterMicrosoftAccountCreatedFunction? onAfterMicrosoftAccountCreated})
Creates a new instance of MicrosoftIdpConfig.

Properties

authorityHost → String
The authority host for the Microsoft identity provider.
final
clientId → String
The client ID from your Microsoft Entra ID (Azure AD) application.
final
clientSecret → String
The client secret from your Microsoft Entra ID (Azure AD) application.
final
fetchProfilePhoto → bool
Whether to automatically fetch and store user profile photos.
final
getExtraMicrosoftInfoCallback → GetExtraMicrosoftInfoCallback?
Callback that can be used with the access token to extract additional information from Microsoft Graph API.
final
hashCode → int
The hash code for this object.
no setterinherited
microsoftAccountDetailsValidation → MicrosoftAccountDetailsValidation
Validation function for Microsoft account details.
final
oauth2Config ↔ OAuth2PkceServerConfig
OAuth2 PKCE server config for Microsoft.
latefinal
onAfterMicrosoftAccountCreated → AfterMicrosoftAccountCreatedFunction?
Callback to be invoked after a new Microsoft account has been created and linked to an auth user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenant → String
The tenant ID or tenant type for the application.
final
type → Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) → MicrosoftIdp
Builds a new instance of the identity provider.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseTokenResponse(Map<String, dynamic> responseBody) → OAuth2PkceTokenResponse
Default Microsoft token response parser for OAuth2PkceServerConfig.
validateMicrosoftAccountDetails(MicrosoftAccountDetails accountDetails) → void
Default validation function for extracting additional Microsoft account details.