microsoftAccountDetailsValidation property

MicrosoftAccountDetailsValidation microsoftAccountDetailsValidation
final

Validation function for Microsoft account details.

This function should throw an exception if the account details do not match the requirements. If the function returns normally, the account is considered valid.

It can be used to enforce additional requirements on the Microsoft account details before allowing the user to sign in. Note that Microsoft users can keep their email private, so email may be null even for valid accounts. Similarly, the name field is optional.

To avoid blocking real users with private profiles from signing in, adjust your validation function with care.

Implementation

final MicrosoftAccountDetailsValidation microsoftAccountDetailsValidation;