MicrosoftIdpUtils class
Utility functions for the Microsoft identity provider.
These functions can be used to compose custom authentication and administration flows if needed.
But for most cases, the methods exposed by MicrosoftIdp and MicrosoftIdpAdmin should be sufficient.
Constructors
- MicrosoftIdpUtils({required MicrosoftIdpConfig config, required AuthUsers authUsers})
- Creates a new instance of MicrosoftIdpUtils.
Properties
- config → MicrosoftIdpConfig
-
Configuration for the Microsoft identity provider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
Session session, {required String accessToken, required Transaction? transaction}) → Future< MicrosoftAuthSuccess> -
Authenticates a user using an
access token. -
exchangeCodeForToken(
Session session, {required String code, required String codeVerifier, required String redirectUri, required bool isWebPlatform}) → Future< String> -
Exchanges an
authorization codefor anaccess token. -
fetchAccountDetails(
Session session, {required String accessToken}) → Future< MicrosoftAccountDetails> -
Returns the account details for the given
accessToken. -
getAccount(
Session session) → Future< MicrosoftAccount?> - Returns the possible MicrosoftAccount associated with a session.
-
linkMicrosoftAuthentication(
Session session, {required UuidValue authUserId, required MicrosoftAccountDetails accountDetails, Transaction? transaction}) → Future< MicrosoftAccount> -
Adds a Microsoft authentication to the given
authUserId. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited