passkeyIdp property
Gets the PasskeyIdp instance from the AuthServices instance.
If you want to use a different instance, override this getter.
Implementation
late final PasskeyIdp passkeyIdp =
AuthServices.getIdentityProvider<PasskeyIdp>();
Gets the PasskeyIdp instance from the AuthServices instance.
If you want to use a different instance, override this getter.
late final PasskeyIdp passkeyIdp =
AuthServices.getIdentityProvider<PasskeyIdp>();