hostname property
The hostname to be used on the web and associated with any apps.
This is also known as the "relying party".
Implementation
final String hostname;
The hostname to be used on the web and associated with any apps.
This is also known as the "relying party".
final String hostname;