PasskeyIdpConfigFromPasswords class

Creates a new PasskeyIdpConfig from keys on the passwords.yaml file.

This constructor requires that a Serverpod instance has already been initialized.

Inheritance

Constructors

PasskeyIdpConfigFromPasswords({Duration challengeLifetime = const Duration(minutes: 5)})
Creates a new PasskeyIdpConfigFromPasswords instance.

Properties

challengeLifetime Duration
Maximum time after which a challenge must have been solved.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hostname String
The hostname to be used on the web and associated with any apps.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) PasskeyIdp
Builds a new instance of the identity provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited