AnonymousAccountRepository class
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<AnonymousAccountTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<AnonymousAccount> rows, {Transaction? transaction})
→ Future<List<AnonymousAccount>>
-
Deletes all AnonymousAccounts in the list and returns the deleted rows.
This is an atomic operation, meaning that if one of the rows fail to
be deleted, none of the rows will be deleted.
-
deleteRow(DatabaseSession session, AnonymousAccount row, {Transaction? transaction})
→ Future<AnonymousAccount>
-
Deletes a single AnonymousAccount.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<AnonymousAccountTable> where, Transaction? transaction})
→ Future<List<AnonymousAccount>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<AnonymousAccountTable>? where, int? limit, int? offset, OrderByBuilder<AnonymousAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<AnonymousAccountTable>? orderByList, Transaction? transaction, AnonymousAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<AnonymousAccount>>
-
Returns a list of AnonymousAccounts matching the given query parameters.
-
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, AnonymousAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<AnonymousAccount?>
-
Finds a single AnonymousAccount by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<AnonymousAccountTable>? where, int? offset, OrderByBuilder<AnonymousAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<AnonymousAccountTable>? orderByList, Transaction? transaction, AnonymousAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<AnonymousAccount?>
-
Returns the first matching AnonymousAccount matching the given query parameters.
-
insert(DatabaseSession session, List<AnonymousAccount> rows, {Transaction? transaction, bool ignoreConflicts = false})
→ Future<List<AnonymousAccount>>
-
Inserts all AnonymousAccounts in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, AnonymousAccount row, {Transaction? transaction})
→ Future<AnonymousAccount>
-
Inserts a single AnonymousAccount and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<AnonymousAccountTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on AnonymousAccount rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<AnonymousAccount> rows, {ColumnSelections<AnonymousAccountTable>? columns, Transaction? transaction})
→ Future<List<AnonymousAccount>>
-
Updates all AnonymousAccounts in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<AnonymousAccountUpdateTable> columnValues, Transaction? transaction})
→ Future<AnonymousAccount?>
-
Updates a single AnonymousAccount by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, AnonymousAccount row, {ColumnSelections<AnonymousAccountTable>? columns, Transaction? transaction})
→ Future<AnonymousAccount>
-
Updates a single AnonymousAccount. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<AnonymousAccountUpdateTable> columnValues, required WhereExpressionBuilder<AnonymousAccountTable> where, int? limit, int? offset, OrderByBuilder<AnonymousAccountTable>? orderBy, OrderByListBuilder<AnonymousAccountTable>? orderByList, bool orderDescending = false, Transaction? transaction})
→ Future<List<AnonymousAccount>>
-
Updates all AnonymousAccounts matching the
where expression with the specified columnValues.
Returns the list of updated rows.