AppleAccountRepository class

Properties

attachRow AppleAccountAttachRowRepository
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<AppleAccountTable>? where, int? limit, Transaction? transaction}) Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<AppleAccount> rows, {OrderByBuilder<AppleAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<AppleAccountTable>? orderByList, Transaction? transaction}) Future<List<AppleAccount>>
Deletes all AppleAccounts in the list and returns the deleted rows.
deleteRow(DatabaseSession session, AppleAccount row, {Transaction? transaction}) Future<AppleAccount>
Deletes a single AppleAccount.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<AppleAccountTable> where, OrderByBuilder<AppleAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<AppleAccountTable>? orderByList, Transaction? transaction}) Future<List<AppleAccount>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<AppleAccountTable>? where, int? limit, int? offset, OrderByBuilder<AppleAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<AppleAccountTable>? orderByList, Transaction? transaction, AppleAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<List<AppleAccount>>
Returns a list of AppleAccounts matching the given query parameters.
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, AppleAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<AppleAccount?>
Finds a single AppleAccount by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<AppleAccountTable>? where, int? offset, OrderByBuilder<AppleAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<AppleAccountTable>? orderByList, Transaction? transaction, AppleAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<AppleAccount?>
Returns the first matching AppleAccount matching the given query parameters.
insert(DatabaseSession session, List<AppleAccount> rows, {Transaction? transaction, bool ignoreConflicts = false}) Future<List<AppleAccount>>
Inserts all AppleAccounts in the list and returns the inserted rows.
insertRow(DatabaseSession session, AppleAccount row, {Transaction? transaction}) Future<AppleAccount>
Inserts a single AppleAccount and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<AppleAccountTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait}) Future<void>
Acquires row-level locks on AppleAccount rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DatabaseSession session, List<AppleAccount> rows, {ColumnSelections<AppleAccountTable>? columns, Transaction? transaction}) Future<List<AppleAccount>>
Updates all AppleAccounts in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<AppleAccountUpdateTable> columnValues, Transaction? transaction}) Future<AppleAccount?>
Updates a single AppleAccount by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, AppleAccount row, {ColumnSelections<AppleAccountTable>? columns, Transaction? transaction}) Future<AppleAccount>
Updates a single AppleAccount. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<AppleAccountUpdateTable> columnValues, required WhereExpressionBuilder<AppleAccountTable> where, int? limit, int? offset, OrderByBuilder<AppleAccountTable>? orderBy, OrderByListBuilder<AppleAccountTable>? orderByList, bool orderDescending = false, Transaction? transaction}) Future<List<AppleAccount>>
Updates all AppleAccounts matching the where expression with the specified columnValues. Returns the list of updated rows.
upsert(DatabaseSession session, List<AppleAccount> rows, {required ColumnSelections<AppleAccountTable> conflictColumns, ColumnSelections<AppleAccountTable>? updateColumns, WhereExpressionBuilder<AppleAccountTable>? updateWhere, Transaction? transaction}) Future<List<AppleAccount>>
Upserts all AppleAccounts in the list and returns the resulting rows.
upsertRow(DatabaseSession session, AppleAccount row, {required ColumnSelections<AppleAccountTable> conflictColumns, ColumnSelections<AppleAccountTable>? updateColumns, WhereExpressionBuilder<AppleAccountTable>? updateWhere, Transaction? transaction}) Future<AppleAccount?>
Upserts a single AppleAccount and returns the resulting row.

Operators

operator ==(Object other) bool
The equality operator.
inherited