lastName property

ColumnString lastName
latefinal

The last name given during the initial registration.

Will only be set if it was requested on sign-up. The user is free to put in whatever they want here, and this is not verified by or known to Apple.

Implementation

late final _i1.ColumnString lastName;