EmailAccountPasswordResetRequestRepository class

Properties

attachRow EmailAccountPasswordResetRequestAttachRowRepository
final
detachRow EmailAccountPasswordResetRequestDetachRowRepository
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<EmailAccountPasswordResetRequestTable>? where, int? limit, Transaction? transaction}) Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<EmailAccountPasswordResetRequest> rows, {OrderByBuilder<EmailAccountPasswordResetRequestTable>? orderBy, OrderByListBuilder<EmailAccountPasswordResetRequestTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<EmailAccountPasswordResetRequest>>
Deletes all EmailAccountPasswordResetRequests in the list and returns the deleted rows.
deleteRow(DatabaseSession session, EmailAccountPasswordResetRequest row, {Transaction? transaction}) Future<EmailAccountPasswordResetRequest>
Deletes a single EmailAccountPasswordResetRequest.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<EmailAccountPasswordResetRequestTable> where, OrderByBuilder<EmailAccountPasswordResetRequestTable>? orderBy, OrderByListBuilder<EmailAccountPasswordResetRequestTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<EmailAccountPasswordResetRequest>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<EmailAccountPasswordResetRequestTable>? where, int? limit, int? offset, OrderByBuilder<EmailAccountPasswordResetRequestTable>? orderBy, OrderByListBuilder<EmailAccountPasswordResetRequestTable>? orderByList, Transaction? transaction, EmailAccountPasswordResetRequestInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<List<EmailAccountPasswordResetRequest>>
Returns a list of EmailAccountPasswordResetRequests matching the given query parameters.
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, EmailAccountPasswordResetRequestInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<EmailAccountPasswordResetRequest?>
Finds a single EmailAccountPasswordResetRequest by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<EmailAccountPasswordResetRequestTable>? where, int? offset, OrderByBuilder<EmailAccountPasswordResetRequestTable>? orderBy, OrderByListBuilder<EmailAccountPasswordResetRequestTable>? orderByList, Transaction? transaction, EmailAccountPasswordResetRequestInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) Future<EmailAccountPasswordResetRequest?>
Returns the first matching EmailAccountPasswordResetRequest matching the given query parameters.
insert(DatabaseSession session, List<EmailAccountPasswordResetRequest> rows, {Transaction? transaction, bool ignoreConflicts = false, bool noReturn = false}) Future<List<EmailAccountPasswordResetRequest>>
Inserts all EmailAccountPasswordResetRequests in the list and returns the inserted rows.
insertRow(DatabaseSession session, EmailAccountPasswordResetRequest row, {Transaction? transaction}) Future<EmailAccountPasswordResetRequest>
Inserts a single EmailAccountPasswordResetRequest and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<EmailAccountPasswordResetRequestTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _is.LockBehavior.wait}) Future<void>
Acquires row-level locks on EmailAccountPasswordResetRequest rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DatabaseSession session, List<EmailAccountPasswordResetRequest> rows, {ColumnSelections<EmailAccountPasswordResetRequestTable>? columns, Transaction? transaction, bool noReturn = false}) Future<List<EmailAccountPasswordResetRequest>>
Updates all EmailAccountPasswordResetRequests in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<EmailAccountPasswordResetRequestUpdateTable> columnValues, Transaction? transaction}) Future<EmailAccountPasswordResetRequest?>
Updates a single EmailAccountPasswordResetRequest by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, EmailAccountPasswordResetRequest row, {ColumnSelections<EmailAccountPasswordResetRequestTable>? columns, Transaction? transaction}) Future<EmailAccountPasswordResetRequest>
Updates a single EmailAccountPasswordResetRequest. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<EmailAccountPasswordResetRequestUpdateTable> columnValues, required WhereExpressionBuilder<EmailAccountPasswordResetRequestTable> where, int? limit, int? offset, OrderByBuilder<EmailAccountPasswordResetRequestTable>? orderBy, OrderByListBuilder<EmailAccountPasswordResetRequestTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<EmailAccountPasswordResetRequest>>
Updates all EmailAccountPasswordResetRequests matching the where expression with the specified columnValues. Returns the list of updated rows.
upsert(DatabaseSession session, List<EmailAccountPasswordResetRequest> rows, {required ColumnSelections<EmailAccountPasswordResetRequestTable> conflictColumns, ColumnSelections<EmailAccountPasswordResetRequestTable>? updateColumns, WhereExpressionBuilder<EmailAccountPasswordResetRequestTable>? updateWhere, Transaction? transaction, bool noReturn = false}) Future<List<EmailAccountPasswordResetRequest>>
Upserts all EmailAccountPasswordResetRequests in the list and returns the resulting rows.
upsertRow(DatabaseSession session, EmailAccountPasswordResetRequest row, {required ColumnSelections<EmailAccountPasswordResetRequestTable> conflictColumns, ColumnSelections<EmailAccountPasswordResetRequestTable>? updateColumns, WhereExpressionBuilder<EmailAccountPasswordResetRequestTable>? updateWhere, Transaction? transaction}) Future<EmailAccountPasswordResetRequest?>
Upserts a single EmailAccountPasswordResetRequest and returns the resulting row.

Operators

operator ==(Object other) bool
The equality operator.
inherited