EmailAccountRepository class
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<EmailAccountTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<EmailAccount> rows, {OrderByBuilder<EmailAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<EmailAccountTable>? orderByList, Transaction? transaction})
→ Future<List<EmailAccount>>
-
Deletes all EmailAccounts in the list and returns the deleted rows.
-
deleteRow(DatabaseSession session, EmailAccount row, {Transaction? transaction})
→ Future<EmailAccount>
-
Deletes a single EmailAccount.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<EmailAccountTable> where, OrderByBuilder<EmailAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<EmailAccountTable>? orderByList, Transaction? transaction})
→ Future<List<EmailAccount>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<EmailAccountTable>? where, int? limit, int? offset, OrderByBuilder<EmailAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<EmailAccountTable>? orderByList, Transaction? transaction, EmailAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<EmailAccount>>
-
Returns a list of EmailAccounts matching the given query parameters.
-
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, EmailAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<EmailAccount?>
-
Finds a single EmailAccount by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<EmailAccountTable>? where, int? offset, OrderByBuilder<EmailAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<EmailAccountTable>? orderByList, Transaction? transaction, EmailAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<EmailAccount?>
-
Returns the first matching EmailAccount matching the given query parameters.
-
insert(DatabaseSession session, List<EmailAccount> rows, {Transaction? transaction, bool ignoreConflicts = false})
→ Future<List<EmailAccount>>
-
Inserts all EmailAccounts in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, EmailAccount row, {Transaction? transaction})
→ Future<EmailAccount>
-
Inserts a single EmailAccount and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<EmailAccountTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on EmailAccount rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<EmailAccount> rows, {ColumnSelections<EmailAccountTable>? columns, Transaction? transaction})
→ Future<List<EmailAccount>>
-
Updates all EmailAccounts in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<EmailAccountUpdateTable> columnValues, Transaction? transaction})
→ Future<EmailAccount?>
-
Updates a single EmailAccount by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, EmailAccount row, {ColumnSelections<EmailAccountTable>? columns, Transaction? transaction})
→ Future<EmailAccount>
-
Updates a single EmailAccount. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<EmailAccountUpdateTable> columnValues, required WhereExpressionBuilder<EmailAccountTable> where, int? limit, int? offset, OrderByBuilder<EmailAccountTable>? orderBy, OrderByListBuilder<EmailAccountTable>? orderByList, bool orderDescending = false, Transaction? transaction})
→ Future<List<EmailAccount>>
-
Updates all EmailAccounts matching the
where expression with the specified columnValues.
Returns the list of updated rows.
-
upsert(DatabaseSession session, List<EmailAccount> rows, {required ColumnSelections<EmailAccountTable> conflictColumns, ColumnSelections<EmailAccountTable>? updateColumns, WhereExpressionBuilder<EmailAccountTable>? updateWhere, Transaction? transaction})
→ Future<List<EmailAccount>>
-
Upserts all EmailAccounts in the list and returns the resulting rows.
-
upsertRow(DatabaseSession session, EmailAccount row, {required ColumnSelections<EmailAccountTable> conflictColumns, ColumnSelections<EmailAccountTable>? updateColumns, WhereExpressionBuilder<EmailAccountTable>? updateWhere, Transaction? transaction})
→ Future<EmailAccount?>
-
Upserts a single EmailAccount and returns the resulting row.