EmailAccountRequestExceptionReason enum

The reason for why the account creation with email request was rejected.

Inheritance
Available extensions

Values

expired → const EmailAccountRequestExceptionReason

Exception to be thrown when attempting to complete a valid email account request that has already expired.

invalid → const EmailAccountRequestExceptionReason

Exception to be thrown when attempting to complete an email account request with an invalid verification code or account request id.

policyViolation → const EmailAccountRequestExceptionReason

Exception to be thrown when attempting to set a password which does not match the configured policy.

tooManyAttempts → const EmailAccountRequestExceptionReason

Exception to be thrown when attempting to complete an email account request too many times.

unknown → const EmailAccountRequestExceptionReason

Unknown error occurred.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Returns a serialized JSON structure of the model which also includes fields used by the database.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EmailAccountRequestExceptionReason>
A constant List of the values in this enum, in order of their declaration.