EmailAccountRequestRepository class
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<EmailAccountRequestTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<EmailAccountRequest> rows, {OrderByBuilder<EmailAccountRequestTable>? orderBy, bool orderDescending = false, OrderByListBuilder<EmailAccountRequestTable>? orderByList, Transaction? transaction, bool noReturn = false})
→ Future<List<EmailAccountRequest>>
-
Deletes all EmailAccountRequests in the list and returns the deleted rows.
-
deleteRow(DatabaseSession session, EmailAccountRequest row, {Transaction? transaction})
→ Future<EmailAccountRequest>
-
Deletes a single EmailAccountRequest.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<EmailAccountRequestTable> where, OrderByBuilder<EmailAccountRequestTable>? orderBy, bool orderDescending = false, OrderByListBuilder<EmailAccountRequestTable>? orderByList, Transaction? transaction, bool noReturn = false})
→ Future<List<EmailAccountRequest>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<EmailAccountRequestTable>? where, int? limit, int? offset, OrderByBuilder<EmailAccountRequestTable>? orderBy, bool orderDescending = false, OrderByListBuilder<EmailAccountRequestTable>? orderByList, Transaction? transaction, EmailAccountRequestInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<EmailAccountRequest>>
-
Returns a list of EmailAccountRequests matching the given query parameters.
-
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, EmailAccountRequestInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<EmailAccountRequest?>
-
Finds a single EmailAccountRequest by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<EmailAccountRequestTable>? where, int? offset, OrderByBuilder<EmailAccountRequestTable>? orderBy, bool orderDescending = false, OrderByListBuilder<EmailAccountRequestTable>? orderByList, Transaction? transaction, EmailAccountRequestInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<EmailAccountRequest?>
-
Returns the first matching EmailAccountRequest matching the given query parameters.
-
insert(DatabaseSession session, List<EmailAccountRequest> rows, {Transaction? transaction, bool ignoreConflicts = false, bool noReturn = false})
→ Future<List<EmailAccountRequest>>
-
Inserts all EmailAccountRequests in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, EmailAccountRequest row, {Transaction? transaction})
→ Future<EmailAccountRequest>
-
Inserts a single EmailAccountRequest and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<EmailAccountRequestTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on EmailAccountRequest rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<EmailAccountRequest> rows, {ColumnSelections<EmailAccountRequestTable>? columns, Transaction? transaction, bool noReturn = false})
→ Future<List<EmailAccountRequest>>
-
Updates all EmailAccountRequests in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<EmailAccountRequestUpdateTable> columnValues, Transaction? transaction})
→ Future<EmailAccountRequest?>
-
Updates a single EmailAccountRequest by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, EmailAccountRequest row, {ColumnSelections<EmailAccountRequestTable>? columns, Transaction? transaction})
→ Future<EmailAccountRequest>
-
Updates a single EmailAccountRequest. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<EmailAccountRequestUpdateTable> columnValues, required WhereExpressionBuilder<EmailAccountRequestTable> where, int? limit, int? offset, OrderByBuilder<EmailAccountRequestTable>? orderBy, OrderByListBuilder<EmailAccountRequestTable>? orderByList, bool orderDescending = false, Transaction? transaction, bool noReturn = false})
→ Future<List<EmailAccountRequest>>
-
Updates all EmailAccountRequests matching the
where expression with the specified columnValues.
Returns the list of updated rows.
-
upsert(DatabaseSession session, List<EmailAccountRequest> rows, {required ColumnSelections<EmailAccountRequestTable> conflictColumns, ColumnSelections<EmailAccountRequestTable>? updateColumns, WhereExpressionBuilder<EmailAccountRequestTable>? updateWhere, Transaction? transaction, bool noReturn = false})
→ Future<List<EmailAccountRequest>>
-
Upserts all EmailAccountRequests in the list and returns the resulting rows.
-
upsertRow(DatabaseSession session, EmailAccountRequest row, {required ColumnSelections<EmailAccountRequestTable> conflictColumns, ColumnSelections<EmailAccountRequestTable>? updateColumns, WhereExpressionBuilder<EmailAccountRequestTable>? updateWhere, Transaction? transaction})
→ Future<EmailAccountRequest?>
-
Upserts a single EmailAccountRequest and returns the resulting row.