FacebookAccessTokenVerificationException class abstract

Exception to be thrown if the Facebook access token verification fails.

This is a generic exception that does not expose any details regarding the cause of the failure to avoid leaking information to potential attackers.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() FacebookAccessTokenVerificationException
Returns a shallow copy of this FacebookAccessTokenVerificationException with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited