fullName property
The user's full name from Facebook.
Combined first and last name as provided by Facebook.
Implementation
String? fullName;
The user's full name from Facebook.
Combined first and last name as provided by Facebook.
String? fullName;