FacebookAccountTable class
Properties
-
authUser
→ AuthUserTable
-
no setter
-
authUserId
↔ ColumnUuid
-
latefinal
-
columns
→ List<Column>
-
List of
Column used by the table.
no setter
-
createdAt
↔ ColumnDateTime
-
The time when this authentication was created.
latefinal
-
email
↔ ColumnString
-
The verified email of the user, as received from Facebook.
latefinal
-
firstName
↔ ColumnString
-
The user's first name from Facebook.
latefinal
-
fullName
↔ ColumnString
-
The user's full name from Facebook.
latefinal
-
hasColumnMapping
→ bool
-
Cached flag indicating whether any columns have explicit column names
that differ from their field names. Computed lazily on first access.
latefinalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
↔ ColumnComparable<UuidValue?>
-
The database id.
latefinalinherited
-
lastName
↔ ColumnString
-
The user's last name from Facebook.
latefinal
-
managedColumns
→ List<Column>
-
List of
Column that are managed by this table.
This is mostly used to exclude columns created by implicit relations.
no setterinherited
-
queryPrefix
→ String
-
Query prefix for
Columns of the table.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
tableName
→ String
-
Name of the table as used in the database.
finalinherited
-
tableRelation
→ TableRelation?
-
Table relation for
Columns of the table.
finalinherited
-
updateTable
↔ FacebookAccountUpdateTable
-
latefinal
-
userIdentifier
↔ ColumnString
-
The Facebook-provided user identifier (Facebook User ID).
latefinal
Methods
-
getRelationTable(String relationField)
→ Table?
-
Returns
TableColumnRelation for the given relationField. If no relation
exists, returns null. The return must be dynamic to allow for relations
with different id types.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited