FirebaseAccountRepository class
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<FirebaseAccountTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<FirebaseAccount> rows, {Transaction? transaction})
→ Future<List<FirebaseAccount>>
-
Deletes all FirebaseAccounts in the list and returns the deleted rows.
This is an atomic operation, meaning that if one of the rows fail to
be deleted, none of the rows will be deleted.
-
deleteRow(DatabaseSession session, FirebaseAccount row, {Transaction? transaction})
→ Future<FirebaseAccount>
-
Deletes a single FirebaseAccount.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<FirebaseAccountTable> where, Transaction? transaction})
→ Future<List<FirebaseAccount>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<FirebaseAccountTable>? where, int? limit, int? offset, OrderByBuilder<FirebaseAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<FirebaseAccountTable>? orderByList, Transaction? transaction, FirebaseAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<FirebaseAccount>>
-
Returns a list of FirebaseAccounts matching the given query parameters.
-
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, FirebaseAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<FirebaseAccount?>
-
Finds a single FirebaseAccount by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<FirebaseAccountTable>? where, int? offset, OrderByBuilder<FirebaseAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<FirebaseAccountTable>? orderByList, Transaction? transaction, FirebaseAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<FirebaseAccount?>
-
Returns the first matching FirebaseAccount matching the given query parameters.
-
insert(DatabaseSession session, List<FirebaseAccount> rows, {Transaction? transaction, bool ignoreConflicts = false})
→ Future<List<FirebaseAccount>>
-
Inserts all FirebaseAccounts in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, FirebaseAccount row, {Transaction? transaction})
→ Future<FirebaseAccount>
-
Inserts a single FirebaseAccount and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<FirebaseAccountTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on FirebaseAccount rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<FirebaseAccount> rows, {ColumnSelections<FirebaseAccountTable>? columns, Transaction? transaction})
→ Future<List<FirebaseAccount>>
-
Updates all FirebaseAccounts in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<FirebaseAccountUpdateTable> columnValues, Transaction? transaction})
→ Future<FirebaseAccount?>
-
Updates a single FirebaseAccount by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, FirebaseAccount row, {ColumnSelections<FirebaseAccountTable>? columns, Transaction? transaction})
→ Future<FirebaseAccount>
-
Updates a single FirebaseAccount. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<FirebaseAccountUpdateTable> columnValues, required WhereExpressionBuilder<FirebaseAccountTable> where, int? limit, int? offset, OrderByBuilder<FirebaseAccountTable>? orderBy, OrderByListBuilder<FirebaseAccountTable>? orderByList, bool orderDescending = false, Transaction? transaction})
→ Future<List<FirebaseAccount>>
-
Updates all FirebaseAccounts matching the
where expression with the specified columnValues.
Returns the list of updated rows.