FirebaseEmailNotVerifiedException class abstract

Exception to be thrown when a Firebase account's email has not been verified, but the configured validation requires it.

This is only thrown when the Firebase identity provider is configured with FirebaseIdpConfig.requireVerifiedEmail (or a custom validation that throws it). Clients can catch this to prompt the user to verify their email address.

Implemented types

Constructors

FirebaseEmailNotVerifiedException()
factory
FirebaseEmailNotVerifiedException.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() → FirebaseEmailNotVerifiedException
Returns a shallow copy of this FirebaseEmailNotVerifiedException with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited