GitHubAccount class abstract

A fully configured GitHub account to be used for logins.

Constructors

GitHubAccount({UuidValue? id, required UuidValue authUserId, AuthUser? authUser, required String userIdentifier, String? email, DateTime? created})
factory
GitHubAccount.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

authUser ↔ AuthUser?
The AuthUser this profile belongs to
getter/setter pair
authUserId ↔ UuidValue
getter/setter pair
created ↔ DateTime
The time when this authentication was created.
getter/setter pair
email ↔ String?
The verified email of the user, as received from GitHub.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ UuidValue?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → Table<UuidValue?>
The table that this row belongs to.
no setter
userIdentifier ↔ String
The user identifier given by GitHub for this account.
getter/setter pair

Methods

copyWith({UuidValue? id, UuidValue? authUserId, AuthUser? authUser, String? userIdentifier, String? email, DateTime? created}) → GitHubAccount
Returns a shallow copy of this GitHubAccount with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toJsonForProtocol() → Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

t → GitHubAccountTable
final

Static Methods

include({AuthUserInclude? authUser}) → GitHubAccountInclude
includeList({WhereExpressionBuilder<GitHubAccountTable>? where, int? limit, int? offset, OrderByBuilder<GitHubAccountTable>? orderBy, OrderByListBuilder<GitHubAccountTable>? orderByList, GitHubAccountInclude? include}) → GitHubAccountIncludeList

Constants

db → const GitHubAccountRepository