GoogleAccountRepository class
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<GoogleAccountTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<GoogleAccount> rows, {Transaction? transaction})
→ Future<List<GoogleAccount>>
-
Deletes all GoogleAccounts in the list and returns the deleted rows.
This is an atomic operation, meaning that if one of the rows fail to
be deleted, none of the rows will be deleted.
-
deleteRow(DatabaseSession session, GoogleAccount row, {Transaction? transaction})
→ Future<GoogleAccount>
-
Deletes a single GoogleAccount.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<GoogleAccountTable> where, Transaction? transaction})
→ Future<List<GoogleAccount>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<GoogleAccountTable>? where, int? limit, int? offset, OrderByBuilder<GoogleAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<GoogleAccountTable>? orderByList, Transaction? transaction, GoogleAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<GoogleAccount>>
-
Returns a list of GoogleAccounts matching the given query parameters.
-
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, GoogleAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<GoogleAccount?>
-
Finds a single GoogleAccount by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<GoogleAccountTable>? where, int? offset, OrderByBuilder<GoogleAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<GoogleAccountTable>? orderByList, Transaction? transaction, GoogleAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<GoogleAccount?>
-
Returns the first matching GoogleAccount matching the given query parameters.
-
insert(DatabaseSession session, List<GoogleAccount> rows, {Transaction? transaction, bool ignoreConflicts = false})
→ Future<List<GoogleAccount>>
-
Inserts all GoogleAccounts in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, GoogleAccount row, {Transaction? transaction})
→ Future<GoogleAccount>
-
Inserts a single GoogleAccount and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<GoogleAccountTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on GoogleAccount rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<GoogleAccount> rows, {ColumnSelections<GoogleAccountTable>? columns, Transaction? transaction})
→ Future<List<GoogleAccount>>
-
Updates all GoogleAccounts in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<GoogleAccountUpdateTable> columnValues, Transaction? transaction})
→ Future<GoogleAccount?>
-
Updates a single GoogleAccount by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, GoogleAccount row, {ColumnSelections<GoogleAccountTable>? columns, Transaction? transaction})
→ Future<GoogleAccount>
-
Updates a single GoogleAccount. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<GoogleAccountUpdateTable> columnValues, required WhereExpressionBuilder<GoogleAccountTable> where, int? limit, int? offset, OrderByBuilder<GoogleAccountTable>? orderBy, OrderByListBuilder<GoogleAccountTable>? orderByList, bool orderDescending = false, Transaction? transaction})
→ Future<List<GoogleAccount>>
-
Updates all GoogleAccounts matching the
where expression with the specified columnValues.
Returns the list of updated rows.