MicrosoftAccountRepository class

Properties

attachRow → MicrosoftAccountAttachRowRepository
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<MicrosoftAccountTable>? where, int? limit, Transaction? transaction}) → Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<MicrosoftAccount> rows, {OrderByBuilder<MicrosoftAccountTable>? orderBy, OrderByListBuilder<MicrosoftAccountTable>? orderByList, Transaction? transaction, bool noReturn = false}) → Future<List<MicrosoftAccount>>
Deletes all MicrosoftAccounts in the list and returns the deleted rows.
deleteRow(DatabaseSession session, MicrosoftAccount row, {Transaction? transaction}) → Future<MicrosoftAccount>
Deletes a single MicrosoftAccount.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<MicrosoftAccountTable> where, OrderByBuilder<MicrosoftAccountTable>? orderBy, OrderByListBuilder<MicrosoftAccountTable>? orderByList, Transaction? transaction, bool noReturn = false}) → Future<List<MicrosoftAccount>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<MicrosoftAccountTable>? where, int? limit, int? offset, OrderByBuilder<MicrosoftAccountTable>? orderBy, OrderByListBuilder<MicrosoftAccountTable>? orderByList, Transaction? transaction, MicrosoftAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) → Future<List<MicrosoftAccount>>
Returns a list of MicrosoftAccounts matching the given query parameters.
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, MicrosoftAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) → Future<MicrosoftAccount?>
Finds a single MicrosoftAccount by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<MicrosoftAccountTable>? where, int? offset, OrderByBuilder<MicrosoftAccountTable>? orderBy, OrderByListBuilder<MicrosoftAccountTable>? orderByList, Transaction? transaction, MicrosoftAccountInclude? include, LockMode? lockMode, LockBehavior? lockBehavior}) → Future<MicrosoftAccount?>
Returns the first matching MicrosoftAccount matching the given query parameters.
insert(DatabaseSession session, List<MicrosoftAccount> rows, {Transaction? transaction, bool ignoreConflicts = false, bool noReturn = false}) → Future<List<MicrosoftAccount>>
Inserts all MicrosoftAccounts in the list and returns the inserted rows.
insertRow(DatabaseSession session, MicrosoftAccount row, {Transaction? transaction}) → Future<MicrosoftAccount>
Inserts a single MicrosoftAccount and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<MicrosoftAccountTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _is.LockBehavior.wait}) → Future<void>
Acquires row-level locks on MicrosoftAccount rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(DatabaseSession session, List<MicrosoftAccount> rows, {ColumnSelections<MicrosoftAccountTable>? columns, Transaction? transaction, bool noReturn = false}) → Future<List<MicrosoftAccount>>
Updates all MicrosoftAccounts in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<MicrosoftAccountUpdateTable> columnValues, Transaction? transaction}) → Future<MicrosoftAccount?>
Updates a single MicrosoftAccount by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, MicrosoftAccount row, {ColumnSelections<MicrosoftAccountTable>? columns, Transaction? transaction}) → Future<MicrosoftAccount>
Updates a single MicrosoftAccount. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<MicrosoftAccountUpdateTable> columnValues, required WhereExpressionBuilder<MicrosoftAccountTable> where, int? limit, int? offset, OrderByBuilder<MicrosoftAccountTable>? orderBy, OrderByListBuilder<MicrosoftAccountTable>? orderByList, Transaction? transaction, bool noReturn = false}) → Future<List<MicrosoftAccount>>
Updates all MicrosoftAccounts matching the where expression with the specified columnValues. Returns the list of updated rows.
upsert(DatabaseSession session, List<MicrosoftAccount> rows, {required ColumnSelections<MicrosoftAccountTable> conflictColumns, ColumnSelections<MicrosoftAccountTable>? updateColumns, WhereExpressionBuilder<MicrosoftAccountTable>? updateWhere, Transaction? transaction, bool noReturn = false}) → Future<List<MicrosoftAccount>>
Upserts all MicrosoftAccounts in the list and returns the resulting rows.
upsertRow(DatabaseSession session, MicrosoftAccount row, {required ColumnSelections<MicrosoftAccountTable> conflictColumns, ColumnSelections<MicrosoftAccountTable>? updateColumns, WhereExpressionBuilder<MicrosoftAccountTable>? updateWhere, Transaction? transaction}) → Future<MicrosoftAccount?>
Upserts a single MicrosoftAccount and returns the resulting row.

Operators

operator ==(Object other) → bool
The equality operator.
inherited