PasskeyAccount class abstract

A fully configured passkey to be used for logins.

Constructors

PasskeyAccount({UuidValue? id, required UuidValue authUserId, AuthUser? authUser, DateTime? createdAt, required ByteData keyId, required String keyIdBase64, required ByteData clientDataJSON, required ByteData attestationObject, required ByteData originalChallenge})
factory
PasskeyAccount.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

attestationObject ByteData
The attestation object used during the registration.
getter/setter pair
authUser AuthUser?
The AuthUser this profile belongs to
getter/setter pair
authUserId ↔ UuidValue
getter/setter pair
clientDataJSON ByteData
The authenticator's JSON client data sent during the registration.
getter/setter pair
createdAt DateTime
The time when this authentication was created.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id ↔ UuidValue?
The id column of the row. Can be null if this row is not yet stored in the database.
getter/setter pair
keyId ByteData
The ID of the publicKey.
getter/setter pair
keyIdBase64 String
Base64 variant of the key ID (to enable DB lookups).
getter/setter pair
originalChallenge ByteData
The challenge used during registration.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table → Table<UuidValue?>
The table that this row belongs to.
no setter

Methods

copyWith({UuidValue? id, UuidValue? authUserId, AuthUser? authUser, DateTime? createdAt, ByteData? keyId, String? keyIdBase64, ByteData? clientDataJSON, ByteData? attestationObject, ByteData? originalChallenge}) PasskeyAccount
Returns a shallow copy of this PasskeyAccount with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

t PasskeyAccountTable
final

Static Methods

include({AuthUserInclude? authUser}) PasskeyAccountInclude
includeList({WhereExpressionBuilder<PasskeyAccountTable>? where, int? limit, int? offset, OrderByBuilder<PasskeyAccountTable>? orderBy, bool orderDescending = false, OrderByListBuilder<PasskeyAccountTable>? orderByList, PasskeyAccountInclude? include}) PasskeyAccountIncludeList

Constants

db → const PasskeyAccountRepository