PasskeyAccountTable class

Constructors

PasskeyAccountTable({TableRelation? tableRelation})

Properties

attestationObject ↔ ColumnByteData
The attestation object used during the registration.
latefinal
authUser AuthUserTable
no setter
authUserId ↔ ColumnUuid
latefinal
clientDataJSON ↔ ColumnByteData
The authenticator's JSON client data sent during the registration.
latefinal
columns List<Column>
List of Column used by the table.
no setter
createdAt ↔ ColumnDateTime
The time when this authentication was created.
latefinal
hasColumnMapping bool
Cached flag indicating whether any columns have explicit column names that differ from their field names. Computed lazily on first access.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<UuidValue?>
The database id.
latefinalinherited
keyId ↔ ColumnByteData
The ID of the publicKey.
latefinal
keyIdBase64 ↔ ColumnString
Base64 variant of the key ID (to enable DB lookups).
latefinal
managedColumns List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
originalChallenge ↔ ColumnByteData
The challenge used during registration.
latefinal
queryPrefix String
Query prefix for Columns of the table.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
Name of the table as used in the database.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited
updateTable PasskeyAccountUpdateTable
latefinal

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited