PasskeyChallengeRepository class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<PasskeyChallengeTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<PasskeyChallenge> rows, {OrderByBuilder<PasskeyChallengeTable>? orderBy, bool orderDescending = false, OrderByListBuilder<PasskeyChallengeTable>? orderByList, Transaction? transaction})
→ Future<List<PasskeyChallenge>>
-
Deletes all PasskeyChallenges in the list and returns the deleted rows.
-
deleteRow(DatabaseSession session, PasskeyChallenge row, {Transaction? transaction})
→ Future<PasskeyChallenge>
-
Deletes a single PasskeyChallenge.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<PasskeyChallengeTable> where, OrderByBuilder<PasskeyChallengeTable>? orderBy, bool orderDescending = false, OrderByListBuilder<PasskeyChallengeTable>? orderByList, Transaction? transaction})
→ Future<List<PasskeyChallenge>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<PasskeyChallengeTable>? where, int? limit, int? offset, OrderByBuilder<PasskeyChallengeTable>? orderBy, bool orderDescending = false, OrderByListBuilder<PasskeyChallengeTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<PasskeyChallenge>>
-
Returns a list of PasskeyChallenges matching the given query parameters.
-
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<PasskeyChallenge?>
-
Finds a single PasskeyChallenge by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<PasskeyChallengeTable>? where, int? offset, OrderByBuilder<PasskeyChallengeTable>? orderBy, bool orderDescending = false, OrderByListBuilder<PasskeyChallengeTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<PasskeyChallenge?>
-
Returns the first matching PasskeyChallenge matching the given query parameters.
-
insert(DatabaseSession session, List<PasskeyChallenge> rows, {Transaction? transaction, bool ignoreConflicts = false})
→ Future<List<PasskeyChallenge>>
-
Inserts all PasskeyChallenges in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, PasskeyChallenge row, {Transaction? transaction})
→ Future<PasskeyChallenge>
-
Inserts a single PasskeyChallenge and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<PasskeyChallengeTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on PasskeyChallenge rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<PasskeyChallenge> rows, {ColumnSelections<PasskeyChallengeTable>? columns, Transaction? transaction})
→ Future<List<PasskeyChallenge>>
-
Updates all PasskeyChallenges in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<PasskeyChallengeUpdateTable> columnValues, Transaction? transaction})
→ Future<PasskeyChallenge?>
-
Updates a single PasskeyChallenge by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, PasskeyChallenge row, {ColumnSelections<PasskeyChallengeTable>? columns, Transaction? transaction})
→ Future<PasskeyChallenge>
-
Updates a single PasskeyChallenge. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<PasskeyChallengeUpdateTable> columnValues, required WhereExpressionBuilder<PasskeyChallengeTable> where, int? limit, int? offset, OrderByBuilder<PasskeyChallengeTable>? orderBy, OrderByListBuilder<PasskeyChallengeTable>? orderByList, bool orderDescending = false, Transaction? transaction})
→ Future<List<PasskeyChallenge>>
-
Updates all PasskeyChallenges matching the
where expression with the specified columnValues.
Returns the list of updated rows.
-
upsert(DatabaseSession session, List<PasskeyChallenge> rows, {required ColumnSelections<PasskeyChallengeTable> conflictColumns, ColumnSelections<PasskeyChallengeTable>? updateColumns, WhereExpressionBuilder<PasskeyChallengeTable>? updateWhere, Transaction? transaction})
→ Future<List<PasskeyChallenge>>
-
Upserts all PasskeyChallenges in the list and returns the resulting rows.
-
upsertRow(DatabaseSession session, PasskeyChallenge row, {required ColumnSelections<PasskeyChallengeTable> conflictColumns, ColumnSelections<PasskeyChallengeTable>? updateColumns, WhereExpressionBuilder<PasskeyChallengeTable>? updateWhere, Transaction? transaction})
→ Future<PasskeyChallenge?>
-
Upserts a single PasskeyChallenge and returns the resulting row.