PasskeyLoginRequest class abstract

Data to be sent for a Passkey login.

Constructors

PasskeyLoginRequest({required UuidValue challengeId, required ByteData keyId, required ByteData authenticatorData, required ByteData clientDataJSON, required ByteData signature})
factory
PasskeyLoginRequest.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

authenticatorData ByteData
The client authenticator's response data.
getter/setter pair
challengeId ↔ UuidValue
The ID of the solved challenge.
getter/setter pair
clientDataJSON ByteData
The client authenticator's JSON data.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
keyId ByteData
The ID of the key used.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature ByteData
The signature of the client's key on the challenge.
getter/setter pair

Methods

copyWith({UuidValue? challengeId, ByteData? keyId, ByteData? authenticatorData, ByteData? clientDataJSON, ByteData? signature}) PasskeyLoginRequest
Returns a shallow copy of this PasskeyLoginRequest with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toJsonForProtocol() Map<String, dynamic>
Returns a JSON structure of the model, optimized for Protocol communication.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited