RateLimitedRequestAttemptTable class

Constructors

RateLimitedRequestAttemptTable({TableRelation? tableRelation})

Properties

attemptedAt ↔ ColumnDateTime
The time of the attempt.
latefinal
columns List<Column>
List of Column used by the table.
no setter
domain ↔ ColumnString
The domain of the attempt. Example: "email", "sms", etc.
latefinal
extraData ↔ ColumnSerializable<Map<String, String>>
Additional data to be logged for the attempt.
latefinal
hasColumnMapping bool
Cached flag indicating whether any columns have explicit column names that differ from their field names. Computed lazily on first access.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
id ↔ ColumnComparable<UuidValue?>
The database id.
latefinalinherited
ipAddress ↔ ColumnString
The IP address calling the request, in case it is relevant. Should only be used for logging and auditing purposes.
latefinal
managedColumns List<Column>
List of Column that are managed by this table. This is mostly used to exclude columns created by implicit relations.
no setterinherited
nonce ↔ ColumnString
The unique identifier for the request. Can be a request ID, a token, an email address, etc.
latefinal
queryPrefix String
Query prefix for Columns of the table.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source ↔ ColumnString
The source of the attempt. Example: "password_reset", "login_attempt", etc.
latefinal
tableName String
Name of the table as used in the database.
finalinherited
tableRelation → TableRelation?
Table relation for Columns of the table.
finalinherited
updateTable RateLimitedRequestAttemptUpdateTable
latefinal

Methods

getRelationTable(String relationField) → Table?
Returns TableColumnRelation for the given relationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited