SecretChallenge class abstract
Database entity for storing hashed verification codes used in challenge-based authentication flows.
Constructors
- SecretChallenge({UuidValue? id, required String challengeCodeHash})
-
factory
-
SecretChallenge.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- challengeCodeHash ↔ String
-
The hash of the challenge code sent to the user.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ UuidValue?
-
The id column of the row. Can be null if this row is not yet stored in
the database.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
table
→ Table<
UuidValue?> -
The table that this row belongs to.
no setter
Methods
-
copyWith(
{UuidValue? id, String? challengeCodeHash}) → SecretChallenge - Returns a shallow copy of this SecretChallenge with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Returns a serialized JSON structure of the model which also includes fields used by the database.
-
toJsonForProtocol(
) → Map< String, dynamic> - Returns a JSON structure of the model, optimized for Protocol communication.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- t → SecretChallengeTable
-
final
Static Methods
-
include(
) → SecretChallengeInclude -
includeList(
{WhereExpressionBuilder< SecretChallengeTable> ? where, int? limit, int? offset, OrderByBuilder<SecretChallengeTable> ? orderBy, bool orderDescending = false, OrderByListBuilder<SecretChallengeTable> ? orderByList, SecretChallengeInclude? include}) → SecretChallengeIncludeList
Constants
- db → const SecretChallengeRepository