SecretChallengeRepository class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(DatabaseSession session, {WhereExpressionBuilder<SecretChallengeTable>? where, int? limit, Transaction? transaction}) Future<int>
Counts the number of rows matching the where expression. If omitted, will return the count of all rows in the table.
delete(DatabaseSession session, List<SecretChallenge> rows, {OrderByBuilder<SecretChallengeTable>? orderBy, OrderByListBuilder<SecretChallengeTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<SecretChallenge>>
Deletes all SecretChallenges in the list and returns the deleted rows.
deleteRow(DatabaseSession session, SecretChallenge row, {Transaction? transaction}) Future<SecretChallenge>
Deletes a single SecretChallenge.
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<SecretChallengeTable> where, OrderByBuilder<SecretChallengeTable>? orderBy, OrderByListBuilder<SecretChallengeTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<SecretChallenge>>
Deletes all rows matching the where expression.
find(DatabaseSession session, {WhereExpressionBuilder<SecretChallengeTable>? where, int? limit, int? offset, OrderByBuilder<SecretChallengeTable>? orderBy, OrderByListBuilder<SecretChallengeTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<List<SecretChallenge>>
Returns a list of SecretChallenges matching the given query parameters.
findById(DatabaseSession session, UuidValue id, {Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<SecretChallenge?>
Finds a single SecretChallenge by its id or null if no such row exists.
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<SecretChallengeTable>? where, int? offset, OrderByBuilder<SecretChallengeTable>? orderBy, OrderByListBuilder<SecretChallengeTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior}) Future<SecretChallenge?>
Returns the first matching SecretChallenge matching the given query parameters.
insert(DatabaseSession session, List<SecretChallenge> rows, {Transaction? transaction, bool ignoreConflicts = false, bool noReturn = false}) Future<List<SecretChallenge>>
Inserts all SecretChallenges in the list and returns the inserted rows.
insertRow(DatabaseSession session, SecretChallenge row, {Transaction? transaction}) Future<SecretChallenge>
Inserts a single SecretChallenge and returns the inserted row.
lockRows(DatabaseSession session, {required WhereExpressionBuilder<SecretChallengeTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _i1.LockBehavior.wait}) Future<void>
Acquires row-level locks on SecretChallenge rows matching the where expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(DatabaseSession session, List<SecretChallenge> rows, {ColumnSelections<SecretChallengeTable>? columns, Transaction? transaction, bool noReturn = false}) Future<List<SecretChallenge>>
Updates all SecretChallenges in the list and returns the updated rows. If columns is provided, only those columns will be updated. Defaults to all columns. This is an atomic operation, meaning that if one of the rows fails to update, none of the rows will be updated.
updateById(DatabaseSession session, UuidValue id, {required ColumnValueListBuilder<SecretChallengeUpdateTable> columnValues, Transaction? transaction}) Future<SecretChallenge?>
Updates a single SecretChallenge by its id with the specified columnValues. Returns the updated row or null if no row with the given id exists.
updateRow(DatabaseSession session, SecretChallenge row, {ColumnSelections<SecretChallengeTable>? columns, Transaction? transaction}) Future<SecretChallenge>
Updates a single SecretChallenge. The row needs to have its id set. Optionally, a list of columns can be provided to only update those columns. Defaults to all columns.
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<SecretChallengeUpdateTable> columnValues, required WhereExpressionBuilder<SecretChallengeTable> where, int? limit, int? offset, OrderByBuilder<SecretChallengeTable>? orderBy, OrderByListBuilder<SecretChallengeTable>? orderByList, Transaction? transaction, bool noReturn = false}) Future<List<SecretChallenge>>
Updates all SecretChallenges matching the where expression with the specified columnValues. Returns the list of updated rows.
upsert(DatabaseSession session, List<SecretChallenge> rows, {required ColumnSelections<SecretChallengeTable> conflictColumns, ColumnSelections<SecretChallengeTable>? updateColumns, WhereExpressionBuilder<SecretChallengeTable>? updateWhere, Transaction? transaction, bool noReturn = false}) Future<List<SecretChallenge>>
Upserts all SecretChallenges in the list and returns the resulting rows.
upsertRow(DatabaseSession session, SecretChallenge row, {required ColumnSelections<SecretChallengeTable> conflictColumns, ColumnSelections<SecretChallengeTable>? updateColumns, WhereExpressionBuilder<SecretChallengeTable>? updateWhere, Transaction? transaction}) Future<SecretChallenge?>
Upserts a single SecretChallenge and returns the resulting row.

Operators

operator ==(Object other) bool
The equality operator.
inherited