defaultMergeHandler static method
FutureOr<void>
defaultMergeHandler(
- Session session, {
- required UuidValue userToKeepId,
- required UuidValue userToRemoveId,
- required Transaction transaction,
Default merge handler that throws an exception. This is only useful for applications which will never merge accounts.
Implementation
static FutureOr<void> defaultMergeHandler(
final Session session, {
required final UuidValue userToKeepId,
required final UuidValue userToRemoveId,
required final Transaction transaction,
}) => throw Exception(
'Cannot safely merge users without a handler for application-specific '
'logic. If your application supports account-merging, you must configure '
'an [AccountMergeConfig] with a custom function for '
'[applicationMergeHandler].',
);