mergeHooks property
List<AccountMergeHandler>
get
mergeHooks
Callbacks to merge data from additional modules or custom tables. These functions are invoked before any other special merge handlers.
Serverpod's first party auth module automatically migrates Idp account data for all initialized identity providers.
Third-party identity providers implement their account migration behavior through IdentityProvider.mergeAuthUsers.
Implementation
List<AccountMergeHandler> get mergeHooks {
if (_mergeHooks != null) {
return _mergeHooks;
}
return [
defaultIdpMergeHandler,
defaultCoreDataMergeHandler,
?applicationMergeHandler,
defaultMergeCleanupHandler,
];
}