AuthUserRepository class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
count (DatabaseSession session , {WhereExpressionBuilder<AuthUserTable > ? where , int ? limit , Transaction? transaction })
→ Future <int >
Counts the number of rows matching the where expression. If omitted,
will return the count of all rows in the table.
delete (DatabaseSession session , List <AuthUser > rows , {Transaction? transaction })
→ Future <List <AuthUser > >
Deletes all AuthUser s in the list and returns the deleted rows.
This is an atomic operation, meaning that if one of the rows fail to
be deleted, none of the rows will be deleted.
deleteRow (DatabaseSession session , AuthUser row , {Transaction? transaction })
→ Future <AuthUser >
Deletes a single AuthUser .
deleteWhere (DatabaseSession session , {required WhereExpressionBuilder<AuthUserTable > where , Transaction? transaction })
→ Future <List <AuthUser > >
Deletes all rows matching the where expression.
find (DatabaseSession session , {WhereExpressionBuilder<AuthUserTable > ? where , int ? limit , int ? offset , OrderByBuilder<AuthUserTable > ? orderBy , bool orderDescending = false , OrderByListBuilder<AuthUserTable > ? orderByList , Transaction? transaction , LockMode? lockMode , LockBehavior? lockBehavior })
→ Future <List <AuthUser > >
Returns a list of AuthUser s matching the given query parameters.
findById (DatabaseSession session , UuidValue id , {Transaction? transaction , LockMode? lockMode , LockBehavior? lockBehavior })
→ Future <AuthUser ? >
Finds a single AuthUser by its id or null if no such row exists.
findFirstRow (DatabaseSession session , {WhereExpressionBuilder<AuthUserTable > ? where , int ? offset , OrderByBuilder<AuthUserTable > ? orderBy , bool orderDescending = false , OrderByListBuilder<AuthUserTable > ? orderByList , Transaction? transaction , LockMode? lockMode , LockBehavior? lockBehavior })
→ Future <AuthUser ? >
Returns the first matching AuthUser matching the given query parameters.
insert (DatabaseSession session , List <AuthUser > rows , {Transaction? transaction , bool ignoreConflicts = false })
→ Future <List <AuthUser > >
Inserts all AuthUser s in the list and returns the inserted rows.
insertRow (DatabaseSession session , AuthUser row , {Transaction? transaction })
→ Future <AuthUser >
Inserts a single AuthUser and returns the inserted row.
lockRows (DatabaseSession session , {required WhereExpressionBuilder<AuthUserTable > where , required LockMode lockMode , required Transaction transaction , LockBehavior lockBehavior = _i1.LockBehavior.wait })
→ Future <void >
Acquires row-level locks on AuthUser rows matching the where expression.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
update (DatabaseSession session , List <AuthUser > rows , {ColumnSelections<AuthUserTable > ? columns , Transaction? transaction })
→ Future <List <AuthUser > >
Updates all AuthUser s in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
updateById (DatabaseSession session , UuidValue id , {required ColumnValueListBuilder<AuthUserUpdateTable > columnValues , Transaction? transaction })
→ Future <AuthUser ? >
Updates a single AuthUser by its id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
updateRow (DatabaseSession session , AuthUser row , {ColumnSelections<AuthUserTable > ? columns , Transaction? transaction })
→ Future <AuthUser >
Updates a single AuthUser . The row needs to have its id set.
Optionally, a list of columns can be provided to only update those
columns. Defaults to all columns.
updateWhere (DatabaseSession session , {required ColumnValueListBuilder<AuthUserUpdateTable > columnValues , required WhereExpressionBuilder<AuthUserTable > where , int ? limit , int ? offset , OrderByBuilder<AuthUserTable > ? orderBy , OrderByListBuilder<AuthUserTable > ? orderByList , bool orderDescending = false , Transaction? transaction })
→ Future <List <AuthUser > >
Updates all AuthUser s matching the where expression with the specified columnValues.
Returns the list of updated rows.
serverpod_auth_idp_server 3.4.4