refreshTokenExpiresAt method
The expiry of a cookie-delivered refresh token, or null for a browser session cookie.
Implementation
@override
DateTime? refreshTokenExpiresAt() {
// Slack for the delay between minting and the cookie write, so the
// cookie does not outlive the token.
return clock.now().toUtc().add(
jwt.config.refreshTokenLifetime - const Duration(seconds: 10),
);
}