AnonymousIdp class
Main class for the anonymous identity provider. The methods defined here are intended to be called from an endpoint.
- Implemented types
Constructors
- AnonymousIdp(AnonymousIdpConfig config, {required TokenManager tokenManager, AuthUsers authUsers = const AuthUsers(), UserProfiles userProfiles = const UserProfiles()})
-
Creates a new instance of AnonymousIdp.
factory
Properties
- config → AnonymousIdpConfig
-
The configuration for the anonymous identity provider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
The method used when authenticating with the anonymous identity provider.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- utils → AnonymousIdpUtils
-
Utility functions for the anonymous identity provider.
final
Methods
-
login(
Session session, {String? token, Transaction? transaction}) → Future< AuthSuccess> - Creates a new anonymous account and returns its session.
-
mergeAuthUsers(
Session session, {required UuidValue userToKeepId, required UuidValue userToRemoveId, required Transaction transaction}) → Future< void> -
Anonymous accounts do not retain provider data when auth users are
merged. Their database records are removed with the discarded auth user.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited