androidPackageIdentifier property
The Android package identifier for the app using Sign in with Apple.
Required for Android Sign in with Apple to work. If not provided, the web authentication callback route will return a 500 error for Android clients.
Implementation
final String? androidPackageIdentifier;