AppleIdpConfigureRoutes extension
Extension to configure AppleIdp routes on the web server.
- on
-
- Serverpod
Methods
-
configureAppleIdpRoutes(
{String? revokedNotificationRoutePath = '/hooks/apple-notification', String? webAuthenticationCallbackRoutePath = '/auth/apple/callback'}) → void -
Available on Serverpod, provided by the AppleIdpConfigureRoutes extension
Configures the routes for the AppleIdp. Must be called after the web server is initialized. If any of the paths are not provided, its route will not be added.