emailIdp property
EmailIdp
get
emailIdp
Accessor for the configured Email Idp instance. By default this uses the global instance configured in AuthServices.
If you want to use a different instance, override this getter.
Implementation
EmailIdp get emailIdp => AuthServices.instance.emailIdp;