onAfterAccountCreated property
Callback to be invoked after a new email account has been created.
This can be used to perform additional setup tasks, such as creating a user profile or sending a welcome email.
Implementation
final AfterAccountCreatedFunction? onAfterAccountCreated;