onPasswordResetCompleted property
Callback to be invoked after a password reset is successfully completed.
This can be used to perform additional cleanup tasks, such as clearing legacy passwords during migration scenarios.
Implementation
final OnPasswordResetCompletedFunction? onPasswordResetCompleted;