accountCreation property
This class contains utility functions for the email identity provider account creation.
The main entry point is the startRegistration method, which returns a
UuidValue with the ID of the account request.
This class also contains utility functions for administration tasks, such as deleting expired account creations and verifying account creations.
Implementation
late final EmailIdpAccountCreationUtil accountCreation;