ServerpodCloudEmailClient class
Client for the Serverpod Cloud transactional email service.
Sends sign-up and password-reset verification emails on behalf of a
Serverpod Cloud project by calling POST {baseUrl}/api/email/send.
Constructors
- ServerpodCloudEmailClient({String baseUrl = defaultBaseUrl, Duration timeout = defaultTimeout, Client? httpClient})
- Creates a new ServerpodCloudEmailClient.
Properties
- baseUrl → String
-
The base URL of the email service.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
The maximum time to wait for the service to respond before failing.
final
Methods
-
close(
) → void - Closes the underlying HTTP client and frees its resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendEmail(
{required String token, required ServerpodCloudEmailType emailType, required String email, required String projectName, required String authCode}) → Future< void> - Sends a transactional email through the Serverpod Cloud email service.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultBaseUrl → const String
- The default base URL of the Serverpod Cloud email service.
- defaultTimeout → const Duration
- The default maximum time to wait for the service to respond.