FacebookIdpAdmin class

Collection of Facebook-account admin methods.

Constructors

FacebookIdpAdmin({required FacebookIdpUtils utils})
Creates a new instance of FacebookIdpAdmin.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
utils FacebookIdpUtils
Utility functions for the Facebook identity provider.
final

Methods

fetchAccountDetails(Session session, {required String accessToken}) Future<FacebookAccountDetails>
Returns the account details for the given accessToken.
linkFacebookAuthentication(Session session, {required UuidValue authUserId, required FacebookAccountDetails accountDetails, Transaction? transaction}) Future<FacebookAccount>
Adds a Facebook authentication to the given authUserId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

findUserByFacebookUserId(Session session, {required String userIdentifier, Transaction? transaction}) Future<UuidValue?>
Return the AuthUser id for the Facebook user id, if any.