login method
Validates a Facebook access token and either logs in the associated user or creates a new user account if the Facebook account ID is not yet known.
If the access token is invalid or expired, the FacebookAccessTokenVerificationException will be thrown.
Implementation
Future<AuthSuccess> login(
final Session session, {
required final String accessToken,
}) async {
return facebookIdp.login(
session,
accessToken: accessToken,
);
}