FacebookIdpConfig class

Configuration for the Facebook identity provider.

Inheritance
Implementers

Constructors

FacebookIdpConfig({required String appId, required String appSecret, FacebookAccountDetailsValidation facebookAccountDetailsValidation = validateFacebookAccountDetails, GetExtraFacebookInfoCallback? getExtraFacebookInfoCallback, AfterFacebookAccountCreatedFunction? onAfterFacebookAccountCreated})
Creates a new instance of FacebookIdpConfig.
const

Properties

appId → String
The app ID from your Facebook Developer app.
final
appSecret → String
The app secret from your Facebook Developer app.
final
facebookAccountDetailsValidation → FacebookAccountDetailsValidation
Validation function for Facebook account details.
final
getExtraFacebookInfoCallback → GetExtraFacebookInfoCallback?
Callback that can be used with the access token to extract additional information from Facebook Graph API.
final
hashCode → int
The hash code for this object.
no setterinherited
onAfterFacebookAccountCreated → AfterFacebookAccountCreatedFunction?
Callback to be invoked after a new Facebook account has been created and linked to an auth user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
The type of the provider that this builder creates. Used to store the provider in the AuthConfig.
no setterinherited

Methods

build({required TokenManager tokenManager, required AuthUsers authUsers, required UserProfiles userProfiles}) → FacebookIdp
Builds a new instance of the identity provider.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validateFacebookAccountDetails(FacebookAccountDetails accountDetails) → void
Default validation function for extracted Facebook account details.