FacebookIdpUtils class
Utility functions for the Facebook identity provider.
These functions can be used to compose custom authentication and administration flows if needed.
But for most cases, the methods exposed by FacebookIdp and FacebookIdpAdmin should be sufficient.
Constructors
- FacebookIdpUtils({required FacebookIdpConfig config, required AuthUsers authUsers})
- Creates a new instance of FacebookIdpUtils.
Properties
- config → FacebookIdpConfig
-
Configuration for the Facebook identity provider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
Session session, {required String accessToken, required Transaction? transaction}) → Future< FacebookAuthSuccess> - Authenticates a user using a Facebook access token.
-
fetchAccountDetails(
Session session, {required String accessToken}) → Future< FacebookAccountDetails> -
Returns the account details for the given
accessToken. -
getAccount(
Session session) → Future< FacebookAccount?> - Returns the possible FacebookAccount associated with a session.
-
linkFacebookAuthentication(
Session session, {required UuidValue authUserId, required FacebookAccountDetails accountDetails, required Transaction? transaction}) → Future< FacebookAccount> - Links a Facebook authentication to an existing AuthUser.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited