firebaseAccountDetailsValidation property
Validation function for Firebase account details.
This function should throw an exception if the account details do not
match the requirements. If the function returns normally, the account
is considered valid. Thrown exceptions that implement
SerializableException are passed through to the client, while any
other exception surfaces as a generic
FirebaseIdTokenVerificationException.
It can be used to enforce additional requirements on the Firebase account details before allowing the user to sign in, such as requiring a verified email or specific email domains.
By default all account details are accepted, including unverified emails — see validateFirebaseAccountDetails. To reject accounts whose email has not been verified, pass requireVerifiedEmail.
Implementation
final FirebaseAccountDetailsValidation firebaseAccountDetailsValidation;