MicrosoftIdpAdmin class

Collection of Microsoft-account admin methods.

Constructors

MicrosoftIdpAdmin({required MicrosoftIdpUtils utils})
Creates a new instance of MicrosoftIdpAdmin.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
utils → MicrosoftIdpUtils
Utility functions for the Microsoft identity provider.
final

Methods

fetchAccountDetails(Session session, {required String accessToken}) → Future<MicrosoftAccountDetails>
Returns the account details for the given accessToken.
linkMicrosoftAuthentication(Session session, {required UuidValue authUserId, required MicrosoftAccountDetails accountDetails, Transaction? transaction}) → Future<MicrosoftAccount>
Adds a Microsoft authentication to the given authUserId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

findUserByMicrosoftUserId(Session session, {required String userIdentifier, Transaction? transaction}) → Future<UuidValue?>
Return the AuthUser id for the Microsoft user id, if any.