AppleAccountUpdateTable class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
table
→ AppleAccountTable
-
The table instance that this update table operates on.
finalinherited
Methods
-
authUserId(UuidValue value)
→ ColumnValue<UuidValue, UuidValue>
-
-
createdAt(DateTime value)
→ ColumnValue<DateTime, DateTime>
-
-
email(String? value)
→ ColumnValue<String, String>
-
-
firstName(String? value)
→ ColumnValue<String, String>
-
-
isEmailVerified(bool? value)
→ ColumnValue<bool, bool>
-
-
isPrivateEmail(bool? value)
→ ColumnValue<bool, bool>
-
-
lastName(String? value)
→ ColumnValue<String, String>
-
-
lastRefreshedAt(DateTime value)
→ ColumnValue<DateTime, DateTime>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshToken(String value)
→ ColumnValue<String, String>
-
-
refreshTokenRequestedWithBundleIdentifier(bool value)
→ ColumnValue<bool, bool>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
userIdentifier(String value)
→ ColumnValue<String, String>
-