EmailAccountLoginExceptionReason enum
The reason for why the authentication via email credentials was rejected.
Values
- invalidCredentials → const EmailAccountLoginExceptionReason
-
The credentials are either wrong or the email address is not known.
- tooManyAttempts → const EmailAccountLoginExceptionReason
-
Too many attempts made to login with the same email address.
- unknown → const EmailAccountLoginExceptionReason
-
Unknown error occurred.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Returns a serialized JSON structure of the model which also includes fields used by the database.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
values
→ const List<
EmailAccountLoginExceptionReason> - A constant List of the values in this enum, in order of their declaration.