EmailAccountPasswordResetRequest class abstract
Pending email account password reset.
Constructors
- EmailAccountPasswordResetRequest({UuidValue? id, required UuidValue emailAccountId, EmailAccount? emailAccount, DateTime? createdAt, required UuidValue challengeId, SecretChallenge? challenge, UuidValue? setPasswordChallengeId, SecretChallenge? setPasswordChallenge})
-
factory
-
EmailAccountPasswordResetRequest.fromJson(Map<
String, dynamic> jsonSerialization) -
factory
Properties
- challenge ↔ SecretChallenge?
-
The associated challenge for this reset request
getter/setter pair
- challengeId ↔ UuidValue
-
getter/setter pair
- createdAt ↔ DateTime
-
The time when this request was created.
getter/setter pair
- emailAccount ↔ EmailAccount?
-
Email account this reset requests belongs to
getter/setter pair
- emailAccountId ↔ UuidValue
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ UuidValue?
-
The id column of the row. Can be null if this row is not yet stored in
the database.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setPasswordChallenge ↔ SecretChallenge?
-
Used to complete the password reset when setting the password.
This will be set after the password reset challenge has been validated.
getter/setter pair
- setPasswordChallengeId ↔ UuidValue?
-
getter/setter pair
-
table
→ Table<
UuidValue?> -
The table that this row belongs to.
no setter
Methods
-
copyWith(
{UuidValue? id, UuidValue? emailAccountId, EmailAccount? emailAccount, DateTime? createdAt, UuidValue? challengeId, SecretChallenge? challenge, UuidValue? setPasswordChallengeId, SecretChallenge? setPasswordChallenge}) → EmailAccountPasswordResetRequest - Returns a shallow copy of this EmailAccountPasswordResetRequest with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Returns a serialized JSON structure of the model which also includes fields used by the database.
-
toJsonForProtocol(
) → Map< String, dynamic> - Returns a JSON structure of the model, optimized for Protocol communication.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Static Methods
-
include(
{EmailAccountInclude? emailAccount, SecretChallengeInclude? challenge, SecretChallengeInclude? setPasswordChallenge}) → EmailAccountPasswordResetRequestInclude -
includeList(
{WhereExpressionBuilder< EmailAccountPasswordResetRequestTable> ? where, int? limit, int? offset, OrderByBuilder<EmailAccountPasswordResetRequestTable> ? orderBy, bool orderDescending = false, OrderByListBuilder<EmailAccountPasswordResetRequestTable> ? orderByList, EmailAccountPasswordResetRequestInclude? include}) → EmailAccountPasswordResetRequestIncludeList