EmailAccountPasswordResetRequestDetachRowRepository class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPasswordChallenge(DatabaseSession session, EmailAccountPasswordResetRequest emailAccountPasswordResetRequest, {Transaction? transaction}) Future<void>
Detaches the relation between this EmailAccountPasswordResetRequest and the SecretChallenge set in setPasswordChallenge by setting the EmailAccountPasswordResetRequest's foreign key setPasswordChallengeId to null.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited