email property
ColumnString
email
latefinal
The verified email of the user, as received from Microsoft.
Logins all work through the userIdentifier, but the email is retained for consolidation look-ups.
Stored in lower-case.
This may be null if the user's email is not public or verified.
Implementation
late final _i1.ColumnString email;