RateLimitedRequestAttempt class abstract
Database table for tracking rate limited request attempts. A new entry will be created whenever the request is attempted.
Constructors
Properties
- attemptedAt ↔ DateTime
-
The time of the attempt.
getter/setter pair
- domain ↔ String
-
The domain of the attempt.
Example: "email", "sms", etc.
getter/setter pair
-
extraData
↔ Map<
String, String> ? -
Additional data to be logged for the attempt.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ UuidValue?
-
The id column of the row. Can be null if this row is not yet stored in
the database.
getter/setter pair
- ipAddress ↔ String?
-
The IP address calling the request, in case it is relevant.
Should only be used for logging and auditing purposes.
getter/setter pair
- nonce ↔ String
-
The unique identifier for the request.
Can be a request ID, a token, an email address, etc.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ String
-
The source of the attempt.
Example: "password_reset", "login_attempt", etc.
getter/setter pair
-
table
→ Table<
UuidValue?> -
The table that this row belongs to.
no setter
Methods
-
copyWith(
{UuidValue? id, String? domain, String? source, String? nonce, String? ipAddress, DateTime? attemptedAt, Map< String, String> ? extraData}) → RateLimitedRequestAttempt - Returns a shallow copy of this RateLimitedRequestAttempt with some or all fields replaced by the given arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Returns a serialized JSON structure of the model which also includes fields used by the database.
-
toJsonForProtocol(
) → Map< String, dynamic> - Returns a JSON structure of the model, optimized for Protocol communication.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- t → RateLimitedRequestAttemptTable
-
final
Static Methods
-
include(
) → RateLimitedRequestAttemptInclude -
includeList(
{WhereExpressionBuilder< RateLimitedRequestAttemptTable> ? where, int? limit, int? offset, OrderByBuilder<RateLimitedRequestAttemptTable> ? orderBy, bool orderDescending = false, OrderByListBuilder<RateLimitedRequestAttemptTable> ? orderByList, RateLimitedRequestAttemptInclude? include}) → RateLimitedRequestAttemptIncludeList