ipAddress property
The IP address calling the request, in case it is relevant. Should only be used for logging and auditing purposes.
Implementation
String? ipAddress;
The IP address calling the request, in case it is relevant. Should only be used for logging and auditing purposes.
String? ipAddress;