ipAddress property
ColumnString
ipAddress
latefinal
The IP address calling the request, in case it is relevant. Should only be used for logging and auditing purposes.
Implementation
late final _i1.ColumnString ipAddress;